/* Autogenerated unit database (CART trees) for cmu_time_awb */

#include "cst_string.h"
#include "cst_cart.h"
#include "cst_regex.h"

/* Shared value definitions */
DEF_STATIC_CONST_VAL_STRING(val_0000,"0");
DEF_STATIC_CONST_VAL_STRING(val_0001,"n");

/* Cluster lists */
/* (t_midnight) (0 0) */
DEF_STATIC_CONST_VAL_FLOAT(g0000,0);
DEF_STATIC_CONST_VAL_CONS(cl_0000, (void*)&g0000, 0);

/* (ay_midnight) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0001, (void*)&g0000, 0);

/* (n_midnight) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0002, (void*)&g0000, 0);

/* (d_midnight) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0003, (void*)&g0000, 0);

/* (ih_midnight) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0004, (void*)&g0000, 0);

/* (m_midnight) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0005, (void*)&g0000, 0);

/* (ng_evening) (0 4.46832) (1 5.77039) (2 7.01929) (3 5.62978) (4 4.77611) (5 4.4538) */
DEF_STATIC_CONST_VAL_FLOAT(g0002,1);
DEF_STATIC_CONST_VAL_FLOAT(g0004,2);
DEF_STATIC_CONST_VAL_FLOAT(g0006,3);
DEF_STATIC_CONST_VAL_FLOAT(g0008,4);
DEF_STATIC_CONST_VAL_FLOAT(g0010,5);
DEF_STATIC_CONST_VAL_CONS(g0009, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0007, (void*)&g0008, (void*)&g0009);
DEF_STATIC_CONST_VAL_CONS(g0005, (void*)&g0006, (void*)&g0007);
DEF_STATIC_CONST_VAL_CONS(g0003, (void*)&g0004, (void*)&g0005);
DEF_STATIC_CONST_VAL_CONS(g0001, (void*)&g0002, (void*)&g0003);
DEF_STATIC_CONST_VAL_CONS(cl_0006, (void*)&g0000, (void*)&g0001);

/* (ih_evening) (0 7.20589) (1 9.25119) (2 9.25285) (3 7.40305) (4 7.18123) (5 6.92136) */
DEF_STATIC_CONST_VAL_CONS(g0015, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0014, (void*)&g0008, (void*)&g0015);
DEF_STATIC_CONST_VAL_CONS(g0013, (void*)&g0006, (void*)&g0014);
DEF_STATIC_CONST_VAL_CONS(g0012, (void*)&g0004, (void*)&g0013);
DEF_STATIC_CONST_VAL_CONS(g0011, (void*)&g0002, (void*)&g0012);
DEF_STATIC_CONST_VAL_CONS(cl_0007, (void*)&g0000, (void*)&g0011);

/* (n_evening) (0 9.17506) (1 9.89501) (2 12.1722) (3 9.77395) (4 9.49462) (5 10.3268) */
DEF_STATIC_CONST_VAL_CONS(g0020, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0019, (void*)&g0008, (void*)&g0020);
DEF_STATIC_CONST_VAL_CONS(g0018, (void*)&g0006, (void*)&g0019);
DEF_STATIC_CONST_VAL_CONS(g0017, (void*)&g0004, (void*)&g0018);
DEF_STATIC_CONST_VAL_CONS(g0016, (void*)&g0002, (void*)&g0017);
DEF_STATIC_CONST_VAL_CONS(cl_0008, (void*)&g0000, (void*)&g0016);

/* (v_evening) (0 7.81835) (1 8.24125) (2 10.5953) (3 8.73453) (4 10.0808) (5 9.03235) */
DEF_STATIC_CONST_VAL_CONS(g0025, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0024, (void*)&g0008, (void*)&g0025);
DEF_STATIC_CONST_VAL_CONS(g0023, (void*)&g0006, (void*)&g0024);
DEF_STATIC_CONST_VAL_CONS(g0022, (void*)&g0004, (void*)&g0023);
DEF_STATIC_CONST_VAL_CONS(g0021, (void*)&g0002, (void*)&g0022);
DEF_STATIC_CONST_VAL_CONS(cl_0009, (void*)&g0000, (void*)&g0021);

/* (iy_evening) (0 8.56708) (1 10.4792) (2 9.6014) (3 7.94012) (4 12.2516) (5 12.3443) */
DEF_STATIC_CONST_VAL_CONS(g0030, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0029, (void*)&g0008, (void*)&g0030);
DEF_STATIC_CONST_VAL_CONS(g0028, (void*)&g0006, (void*)&g0029);
DEF_STATIC_CONST_VAL_CONS(g0027, (void*)&g0004, (void*)&g0028);
DEF_STATIC_CONST_VAL_CONS(g0026, (void*)&g0002, (void*)&g0027);
DEF_STATIC_CONST_VAL_CONS(cl_0010, (void*)&g0000, (void*)&g0026);

/* (uw_afternoon) (0 10.5003) (1 7.67318) (2 7.97344) (3 8.34433) (4 8.03152) */
DEF_STATIC_CONST_VAL_CONS(g0034, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0033, (void*)&g0006, (void*)&g0034);
DEF_STATIC_CONST_VAL_CONS(g0032, (void*)&g0004, (void*)&g0033);
DEF_STATIC_CONST_VAL_CONS(g0031, (void*)&g0002, (void*)&g0032);
DEF_STATIC_CONST_VAL_CONS(cl_0011, (void*)&g0000, (void*)&g0031);

/* (n_afternoon) (0 10.3368) (1 15.4516) (2 11.3473) (3 9.47425) (4 9.58767) (5 10.1923) (6 10.5821) (7 10.3707) (8 10.922) (9 10.5567) */
DEF_STATIC_CONST_VAL_FLOAT(g0041,6);
DEF_STATIC_CONST_VAL_FLOAT(g0043,7);
DEF_STATIC_CONST_VAL_FLOAT(g0045,8);
DEF_STATIC_CONST_VAL_FLOAT(g0047,9);
DEF_STATIC_CONST_VAL_CONS(g0046, (void*)&g0047, 0);
DEF_STATIC_CONST_VAL_CONS(g0044, (void*)&g0045, (void*)&g0046);
DEF_STATIC_CONST_VAL_CONS(g0042, (void*)&g0043, (void*)&g0044);
DEF_STATIC_CONST_VAL_CONS(g0040, (void*)&g0041, (void*)&g0042);
DEF_STATIC_CONST_VAL_CONS(g0039, (void*)&g0010, (void*)&g0040);
DEF_STATIC_CONST_VAL_CONS(g0038, (void*)&g0008, (void*)&g0039);
DEF_STATIC_CONST_VAL_CONS(g0037, (void*)&g0006, (void*)&g0038);
DEF_STATIC_CONST_VAL_CONS(g0036, (void*)&g0004, (void*)&g0037);
DEF_STATIC_CONST_VAL_CONS(g0035, (void*)&g0002, (void*)&g0036);
DEF_STATIC_CONST_VAL_CONS(cl_0012, (void*)&g0000, (void*)&g0035);

/* (er_afternoon) (0 9.78547) (1 7.48023) (2 8.97085) (3 10.3996) (4 7.20807) */
DEF_STATIC_CONST_VAL_CONS(g0051, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0050, (void*)&g0006, (void*)&g0051);
DEF_STATIC_CONST_VAL_CONS(g0049, (void*)&g0004, (void*)&g0050);
DEF_STATIC_CONST_VAL_CONS(g0048, (void*)&g0002, (void*)&g0049);
DEF_STATIC_CONST_VAL_CONS(cl_0013, (void*)&g0000, (void*)&g0048);

/* (t_afternoon) (0 9.85406) (1 8.95087) (2 10.4208) (3 9.46775) (4 9.47444) */
DEF_STATIC_CONST_VAL_CONS(g0055, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0054, (void*)&g0006, (void*)&g0055);
DEF_STATIC_CONST_VAL_CONS(g0053, (void*)&g0004, (void*)&g0054);
DEF_STATIC_CONST_VAL_CONS(g0052, (void*)&g0002, (void*)&g0053);
DEF_STATIC_CONST_VAL_CONS(cl_0014, (void*)&g0000, (void*)&g0052);

/* (f_afternoon) (0 6.85896) (1 5.50629) (2 5.41178) (3 5.20979) (4 5.16983) */
DEF_STATIC_CONST_VAL_CONS(g0059, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0058, (void*)&g0006, (void*)&g0059);
DEF_STATIC_CONST_VAL_CONS(g0057, (void*)&g0004, (void*)&g0058);
DEF_STATIC_CONST_VAL_CONS(g0056, (void*)&g0002, (void*)&g0057);
DEF_STATIC_CONST_VAL_CONS(cl_0015, (void*)&g0000, (void*)&g0056);

/* (ae_afternoon) (0 7.86797) (1 6.20485) (2 4.5437) (3 5.09352) (4 4.60614) */
DEF_STATIC_CONST_VAL_CONS(g0063, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0062, (void*)&g0006, (void*)&g0063);
DEF_STATIC_CONST_VAL_CONS(g0061, (void*)&g0004, (void*)&g0062);
DEF_STATIC_CONST_VAL_CONS(g0060, (void*)&g0002, (void*)&g0061);
DEF_STATIC_CONST_VAL_CONS(cl_0016, (void*)&g0000, (void*)&g0060);

/* (iy_the) (0 9.07974) (1 11.2742) (2 8.82346) (3 8.12628) (4 10.3785) (5 11.4533) (6 8.7086) (7 8.34573) (8 10.258) (9 8.6262) (10 7.99737) */
DEF_STATIC_CONST_VAL_FLOAT(g0074,10);
DEF_STATIC_CONST_VAL_CONS(g0073, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0072, (void*)&g0047, (void*)&g0073);
DEF_STATIC_CONST_VAL_CONS(g0071, (void*)&g0045, (void*)&g0072);
DEF_STATIC_CONST_VAL_CONS(g0070, (void*)&g0043, (void*)&g0071);
DEF_STATIC_CONST_VAL_CONS(g0069, (void*)&g0041, (void*)&g0070);
DEF_STATIC_CONST_VAL_CONS(g0068, (void*)&g0010, (void*)&g0069);
DEF_STATIC_CONST_VAL_CONS(g0067, (void*)&g0008, (void*)&g0068);
DEF_STATIC_CONST_VAL_CONS(g0066, (void*)&g0006, (void*)&g0067);
DEF_STATIC_CONST_VAL_CONS(g0065, (void*)&g0004, (void*)&g0066);
DEF_STATIC_CONST_VAL_CONS(g0064, (void*)&g0002, (void*)&g0065);
DEF_STATIC_CONST_VAL_CONS(cl_0017, (void*)&g0000, (void*)&g0064);

/* (v_twelve) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0018, (void*)&g0000, 0);

/* (l_twelve) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0019, (void*)&g0000, 0);

/* (eh_twelve) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0020, (void*)&g0000, 0);

/* (w_twelve) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0021, (void*)&g0000, 0);

/* (t_twelve) (0 0) */
DEF_STATIC_CONST_VAL_CONS(cl_0022, (void*)&g0000, 0);

/* (n_eleven) (0 6.6403) (1 6.6403) */
DEF_STATIC_CONST_VAL_CONS(g0075, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0023, (void*)&g0000, (void*)&g0075);

/* (ax_eleven) (0 8.82946) (1 8.82946) */
DEF_STATIC_CONST_VAL_CONS(g0076, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0024, (void*)&g0000, (void*)&g0076);

/* (v_eleven) (0 6.11256) (1 6.11256) */
DEF_STATIC_CONST_VAL_CONS(g0077, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0025, (void*)&g0000, (void*)&g0077);

/* (eh_eleven) (0 4.57024) (1 4.57024) */
DEF_STATIC_CONST_VAL_CONS(g0078, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0026, (void*)&g0000, (void*)&g0078);

/* (l_eleven) (0 9.90849) (1 9.90849) */
DEF_STATIC_CONST_VAL_CONS(g0079, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0027, (void*)&g0000, (void*)&g0079);

/* (ih_eleven) (0 9.52747) (1 9.52747) */
DEF_STATIC_CONST_VAL_CONS(g0080, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0028, (void*)&g0000, (void*)&g0080);

/* (ay_nine) (0 7.28102) (1 7.28102) */
DEF_STATIC_CONST_VAL_CONS(g0081, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0029, (void*)&g0000, (void*)&g0081);

/* (n_nine) (0 10.1967) (1 11.2202) (2 8.41088) (3 11.4654) */
DEF_STATIC_CONST_VAL_CONS(g0084, (void*)&g0006, 0);
DEF_STATIC_CONST_VAL_CONS(g0083, (void*)&g0004, (void*)&g0084);
DEF_STATIC_CONST_VAL_CONS(g0082, (void*)&g0002, (void*)&g0083);
DEF_STATIC_CONST_VAL_CONS(cl_0030, (void*)&g0000, (void*)&g0082);

/* (pau_t) (0 11.6663) (1 11.1733) (2 9.90488) */
DEF_STATIC_CONST_VAL_CONS(g0086, (void*)&g0004, 0);
DEF_STATIC_CONST_VAL_CONS(g0085, (void*)&g0002, (void*)&g0086);
DEF_STATIC_CONST_VAL_CONS(cl_0031, (void*)&g0000, (void*)&g0085);

/* (t_eight) (0 9.74673) (1 9.74673) */
DEF_STATIC_CONST_VAL_CONS(g0087, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0032, (void*)&g0000, (void*)&g0087);

/* (ey_eight) (0 9.24998) (1 9.24998) */
DEF_STATIC_CONST_VAL_CONS(g0088, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0033, (void*)&g0000, (void*)&g0088);

/* (n_seven) (0 8.90061) (1 8.90061) */
DEF_STATIC_CONST_VAL_CONS(g0089, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0034, (void*)&g0000, (void*)&g0089);

/* (ax_seven) (0 12.7518) (1 12.7518) */
DEF_STATIC_CONST_VAL_CONS(g0090, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0035, (void*)&g0000, (void*)&g0090);

/* (v_seven) (0 10.8781) (1 10.8781) */
DEF_STATIC_CONST_VAL_CONS(g0091, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0036, (void*)&g0000, (void*)&g0091);

/* (eh_seven) (0 6.99686) (1 6.99686) */
DEF_STATIC_CONST_VAL_CONS(g0092, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0037, (void*)&g0000, (void*)&g0092);

/* (s_seven) (0 11.5853) (1 11.5853) */
DEF_STATIC_CONST_VAL_CONS(g0093, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0038, (void*)&g0000, (void*)&g0093);

/* (ax_to) (0 11.4852) (1 9.95462) (2 8.8526) (3 10.0656) (4 10.4971) (5 13.6645) (6 10.5912) (7 12.5246) (8 11.0177) (9 12.689) (10 12.2666) */
DEF_STATIC_CONST_VAL_CONS(g0103, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0102, (void*)&g0047, (void*)&g0103);
DEF_STATIC_CONST_VAL_CONS(g0101, (void*)&g0045, (void*)&g0102);
DEF_STATIC_CONST_VAL_CONS(g0100, (void*)&g0043, (void*)&g0101);
DEF_STATIC_CONST_VAL_CONS(g0099, (void*)&g0041, (void*)&g0100);
DEF_STATIC_CONST_VAL_CONS(g0098, (void*)&g0010, (void*)&g0099);
DEF_STATIC_CONST_VAL_CONS(g0097, (void*)&g0008, (void*)&g0098);
DEF_STATIC_CONST_VAL_CONS(g0096, (void*)&g0006, (void*)&g0097);
DEF_STATIC_CONST_VAL_CONS(g0095, (void*)&g0004, (void*)&g0096);
DEF_STATIC_CONST_VAL_CONS(g0094, (void*)&g0002, (void*)&g0095);
DEF_STATIC_CONST_VAL_CONS(cl_0039, (void*)&g0000, (void*)&g0094);

/* (t_to) (0 9.68948) (1 7.90986) (2 9.67565) (3 8.84455) (4 9.47149) (5 7.77677) (6 8.01945) (7 11.0958) (8 8.85528) (9 10.2984) (10 8.89296) */
DEF_STATIC_CONST_VAL_CONS(g0113, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0112, (void*)&g0047, (void*)&g0113);
DEF_STATIC_CONST_VAL_CONS(g0111, (void*)&g0045, (void*)&g0112);
DEF_STATIC_CONST_VAL_CONS(g0110, (void*)&g0043, (void*)&g0111);
DEF_STATIC_CONST_VAL_CONS(g0109, (void*)&g0041, (void*)&g0110);
DEF_STATIC_CONST_VAL_CONS(g0108, (void*)&g0010, (void*)&g0109);
DEF_STATIC_CONST_VAL_CONS(g0107, (void*)&g0008, (void*)&g0108);
DEF_STATIC_CONST_VAL_CONS(g0106, (void*)&g0006, (void*)&g0107);
DEF_STATIC_CONST_VAL_CONS(g0105, (void*)&g0004, (void*)&g0106);
DEF_STATIC_CONST_VAL_CONS(g0104, (void*)&g0002, (void*)&g0105);
DEF_STATIC_CONST_VAL_CONS(cl_0040, (void*)&g0000, (void*)&g0104);

/* (pau_s) (0 12.9054) (1 12.9054) */
DEF_STATIC_CONST_VAL_CONS(g0114, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0041, (void*)&g0000, (void*)&g0114);

/* (k_six) (0 6.1029) (1 6.1029) */
DEF_STATIC_CONST_VAL_CONS(g0115, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0042, (void*)&g0000, (void*)&g0115);

/* (ih_six) (0 5.34714) (1 5.34714) */
DEF_STATIC_CONST_VAL_CONS(g0116, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0043, (void*)&g0000, (void*)&g0116);

/* (s_six) (0 13.0103) (1 7.39524) (2 10.5744) (3 10.7571) */
DEF_STATIC_CONST_VAL_CONS(g0119, (void*)&g0006, 0);
DEF_STATIC_CONST_VAL_CONS(g0118, (void*)&g0004, (void*)&g0119);
DEF_STATIC_CONST_VAL_CONS(g0117, (void*)&g0002, (void*)&g0118);
DEF_STATIC_CONST_VAL_CONS(cl_0044, (void*)&g0000, (void*)&g0117);

/* (f_half) (0 9.53554) (1 9.53554) */
DEF_STATIC_CONST_VAL_CONS(g0120, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0045, (void*)&g0000, (void*)&g0120);

/* (ae_half) (0 9.91615) (1 9.91615) */
DEF_STATIC_CONST_VAL_CONS(g0121, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0046, (void*)&g0000, (void*)&g0121);

/* (hh_half) (0 12.781) (1 12.781) */
DEF_STATIC_CONST_VAL_CONS(g0122, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0047, (void*)&g0000, (void*)&g0122);

/* (pau_v) (0 10.0946) (1 11.1791) (2 9.62929) */
DEF_STATIC_CONST_VAL_CONS(g0124, (void*)&g0004, 0);
DEF_STATIC_CONST_VAL_CONS(g0123, (void*)&g0002, (void*)&g0124);
DEF_STATIC_CONST_VAL_CONS(cl_0048, (void*)&g0000, (void*)&g0123);

/* (pau_r) (0 14.7429) (1 14.7429) */
DEF_STATIC_CONST_VAL_CONS(g0125, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0049, (void*)&g0000, (void*)&g0125);

/* (r_four) (0 6.75639) (1 6.75639) */
DEF_STATIC_CONST_VAL_CONS(g0126, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0050, (void*)&g0000, (void*)&g0126);

/* (ao_four) (0 9.3227) (1 9.3227) */
DEF_STATIC_CONST_VAL_CONS(g0127, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0051, (void*)&g0000, (void*)&g0127);

/* (f_four) (0 8.0843) (1 8.0843) */
DEF_STATIC_CONST_VAL_CONS(g0128, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0052, (void*)&g0000, (void*)&g0128);

/* (iy_twenty) (0 7.37307) (1 10.3825) (2 7.8049) (3 8.63121) (4 9.32309) (5 7.61121) (6 7.29232) (7 7.07893) */
DEF_STATIC_CONST_VAL_CONS(g0135, (void*)&g0043, 0);
DEF_STATIC_CONST_VAL_CONS(g0134, (void*)&g0041, (void*)&g0135);
DEF_STATIC_CONST_VAL_CONS(g0133, (void*)&g0010, (void*)&g0134);
DEF_STATIC_CONST_VAL_CONS(g0132, (void*)&g0008, (void*)&g0133);
DEF_STATIC_CONST_VAL_CONS(g0131, (void*)&g0006, (void*)&g0132);
DEF_STATIC_CONST_VAL_CONS(g0130, (void*)&g0004, (void*)&g0131);
DEF_STATIC_CONST_VAL_CONS(g0129, (void*)&g0002, (void*)&g0130);
DEF_STATIC_CONST_VAL_CONS(cl_0053, (void*)&g0000, (void*)&g0129);

/* (n_twenty) (0 6.66334) (1 6.19568) (2 7.9338) (3 8.60165) (4 9.17889) (5 7.27125) (6 6.48564) (7 9.20764) */
DEF_STATIC_CONST_VAL_CONS(g0142, (void*)&g0043, 0);
DEF_STATIC_CONST_VAL_CONS(g0141, (void*)&g0041, (void*)&g0142);
DEF_STATIC_CONST_VAL_CONS(g0140, (void*)&g0010, (void*)&g0141);
DEF_STATIC_CONST_VAL_CONS(g0139, (void*)&g0008, (void*)&g0140);
DEF_STATIC_CONST_VAL_CONS(g0138, (void*)&g0006, (void*)&g0139);
DEF_STATIC_CONST_VAL_CONS(g0137, (void*)&g0004, (void*)&g0138);
DEF_STATIC_CONST_VAL_CONS(g0136, (void*)&g0002, (void*)&g0137);
DEF_STATIC_CONST_VAL_CONS(cl_0054, (void*)&g0000, (void*)&g0136);

/* (eh_twenty) (0 7.81958) (1 7.31525) (2 11.6176) (3 8.88296) (4 8.3319) (5 8.26103) (6 7.44911) (7 10.6736) */
DEF_STATIC_CONST_VAL_CONS(g0149, (void*)&g0043, 0);
DEF_STATIC_CONST_VAL_CONS(g0148, (void*)&g0041, (void*)&g0149);
DEF_STATIC_CONST_VAL_CONS(g0147, (void*)&g0010, (void*)&g0148);
DEF_STATIC_CONST_VAL_CONS(g0146, (void*)&g0008, (void*)&g0147);
DEF_STATIC_CONST_VAL_CONS(g0145, (void*)&g0006, (void*)&g0146);
DEF_STATIC_CONST_VAL_CONS(g0144, (void*)&g0004, (void*)&g0145);
DEF_STATIC_CONST_VAL_CONS(g0143, (void*)&g0002, (void*)&g0144);
DEF_STATIC_CONST_VAL_CONS(cl_0055, (void*)&g0000, (void*)&g0143);

/* (w_twenty) (0 9.34274) (1 10.8719) (2 8.59439) (3 11.3141) (4 9.53102) (5 9.81449) (6 9.55084) (7 8.1071) */
DEF_STATIC_CONST_VAL_CONS(g0156, (void*)&g0043, 0);
DEF_STATIC_CONST_VAL_CONS(g0155, (void*)&g0041, (void*)&g0156);
DEF_STATIC_CONST_VAL_CONS(g0154, (void*)&g0010, (void*)&g0155);
DEF_STATIC_CONST_VAL_CONS(g0153, (void*)&g0008, (void*)&g0154);
DEF_STATIC_CONST_VAL_CONS(g0152, (void*)&g0006, (void*)&g0153);
DEF_STATIC_CONST_VAL_CONS(g0151, (void*)&g0004, (void*)&g0152);
DEF_STATIC_CONST_VAL_CONS(g0150, (void*)&g0002, (void*)&g0151);
DEF_STATIC_CONST_VAL_CONS(cl_0056, (void*)&g0000, (void*)&g0150);

/* (t_twenty) (0 9.70226) (1 10.3561) (2 10.142) (3 12.6607) (4 11.6324) (5 11.0234) (6 10.1125) (7 11.8513) (8 8.88401) (9 11.2823) (10 9.61397) (11 10.61) (12 9.83582) (13 11.505) (14 8.88101) (15 9.7266) */
DEF_STATIC_CONST_VAL_FLOAT(g0168,11);
DEF_STATIC_CONST_VAL_FLOAT(g0170,12);
DEF_STATIC_CONST_VAL_FLOAT(g0172,13);
DEF_STATIC_CONST_VAL_FLOAT(g0174,14);
DEF_STATIC_CONST_VAL_FLOAT(g0176,15);
DEF_STATIC_CONST_VAL_CONS(g0175, (void*)&g0176, 0);
DEF_STATIC_CONST_VAL_CONS(g0173, (void*)&g0174, (void*)&g0175);
DEF_STATIC_CONST_VAL_CONS(g0171, (void*)&g0172, (void*)&g0173);
DEF_STATIC_CONST_VAL_CONS(g0169, (void*)&g0170, (void*)&g0171);
DEF_STATIC_CONST_VAL_CONS(g0167, (void*)&g0168, (void*)&g0169);
DEF_STATIC_CONST_VAL_CONS(g0166, (void*)&g0074, (void*)&g0167);
DEF_STATIC_CONST_VAL_CONS(g0165, (void*)&g0047, (void*)&g0166);
DEF_STATIC_CONST_VAL_CONS(g0164, (void*)&g0045, (void*)&g0165);
DEF_STATIC_CONST_VAL_CONS(g0163, (void*)&g0043, (void*)&g0164);
DEF_STATIC_CONST_VAL_CONS(g0162, (void*)&g0041, (void*)&g0163);
DEF_STATIC_CONST_VAL_CONS(g0161, (void*)&g0010, (void*)&g0162);
DEF_STATIC_CONST_VAL_CONS(g0160, (void*)&g0008, (void*)&g0161);
DEF_STATIC_CONST_VAL_CONS(g0159, (void*)&g0006, (void*)&g0160);
DEF_STATIC_CONST_VAL_CONS(g0158, (void*)&g0004, (void*)&g0159);
DEF_STATIC_CONST_VAL_CONS(g0157, (void*)&g0002, (void*)&g0158);
DEF_STATIC_CONST_VAL_CONS(cl_0057, (void*)&g0000, (void*)&g0157);

/* (t_almost) (0 9.22557) (1 6.94734) (2 9.65907) (3 7.65548) (4 10.7467) (5 9.34317) */
DEF_STATIC_CONST_VAL_CONS(g0181, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0180, (void*)&g0008, (void*)&g0181);
DEF_STATIC_CONST_VAL_CONS(g0179, (void*)&g0006, (void*)&g0180);
DEF_STATIC_CONST_VAL_CONS(g0178, (void*)&g0004, (void*)&g0179);
DEF_STATIC_CONST_VAL_CONS(g0177, (void*)&g0002, (void*)&g0178);
DEF_STATIC_CONST_VAL_CONS(cl_0058, (void*)&g0000, (void*)&g0177);

/* (s_almost) (0 4.49571) (1 3.58703) (2 3.76629) (3 3.60944) (4 4.09811) (5 4.62042) */
DEF_STATIC_CONST_VAL_CONS(g0186, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0185, (void*)&g0008, (void*)&g0186);
DEF_STATIC_CONST_VAL_CONS(g0184, (void*)&g0006, (void*)&g0185);
DEF_STATIC_CONST_VAL_CONS(g0183, (void*)&g0004, (void*)&g0184);
DEF_STATIC_CONST_VAL_CONS(g0182, (void*)&g0002, (void*)&g0183);
DEF_STATIC_CONST_VAL_CONS(cl_0059, (void*)&g0000, (void*)&g0182);

/* (ow_almost) (0 5.72488) (1 5.02194) (2 5.64595) (3 6.37841) (4 5.311) (5 5.54687) */
DEF_STATIC_CONST_VAL_CONS(g0191, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0190, (void*)&g0008, (void*)&g0191);
DEF_STATIC_CONST_VAL_CONS(g0189, (void*)&g0006, (void*)&g0190);
DEF_STATIC_CONST_VAL_CONS(g0188, (void*)&g0004, (void*)&g0189);
DEF_STATIC_CONST_VAL_CONS(g0187, (void*)&g0002, (void*)&g0188);
DEF_STATIC_CONST_VAL_CONS(cl_0060, (void*)&g0000, (void*)&g0187);

/* (m_almost) (0 6.6901) (1 7.49181) (2 6.63491) (3 6.17647) (4 5.91204) (5 6.79105) */
DEF_STATIC_CONST_VAL_CONS(g0196, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0195, (void*)&g0008, (void*)&g0196);
DEF_STATIC_CONST_VAL_CONS(g0194, (void*)&g0006, (void*)&g0195);
DEF_STATIC_CONST_VAL_CONS(g0193, (void*)&g0004, (void*)&g0194);
DEF_STATIC_CONST_VAL_CONS(g0192, (void*)&g0002, (void*)&g0193);
DEF_STATIC_CONST_VAL_CONS(cl_0061, (void*)&g0000, (void*)&g0192);

/* (l_almost) (0 8.34393) (1 8.48961) (2 7.51124) (3 7.627) (4 11.5927) (5 9.07309) */
DEF_STATIC_CONST_VAL_CONS(g0201, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0200, (void*)&g0008, (void*)&g0201);
DEF_STATIC_CONST_VAL_CONS(g0199, (void*)&g0006, (void*)&g0200);
DEF_STATIC_CONST_VAL_CONS(g0198, (void*)&g0004, (void*)&g0199);
DEF_STATIC_CONST_VAL_CONS(g0197, (void*)&g0002, (void*)&g0198);
DEF_STATIC_CONST_VAL_CONS(cl_0062, (void*)&g0000, (void*)&g0197);

/* (ao_almost) (0 6.80871) (1 7.8782) (2 6.08427) (3 7.74825) (4 8.02433) (5 7.98609) */
DEF_STATIC_CONST_VAL_CONS(g0206, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0205, (void*)&g0008, (void*)&g0206);
DEF_STATIC_CONST_VAL_CONS(g0204, (void*)&g0006, (void*)&g0205);
DEF_STATIC_CONST_VAL_CONS(g0203, (void*)&g0004, (void*)&g0204);
DEF_STATIC_CONST_VAL_CONS(g0202, (void*)&g0002, (void*)&g0203);
DEF_STATIC_CONST_VAL_CONS(cl_0063, (void*)&g0000, (void*)&g0202);

/* (pau_iy) (0 5.79885) (1 5.79885) */
DEF_STATIC_CONST_VAL_CONS(g0207, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0064, (void*)&g0000, (void*)&g0207);

/* (iy_three) (0 7.23089) (1 7.23089) */
DEF_STATIC_CONST_VAL_CONS(g0208, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0065, (void*)&g0000, (void*)&g0208);

/* (r_three) (0 8.80363) (1 8.80363) */
DEF_STATIC_CONST_VAL_CONS(g0209, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0066, (void*)&g0000, (void*)&g0209);

/* (th_three) (0 8.72326) (1 8.72326) */
DEF_STATIC_CONST_VAL_CONS(g0210, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0067, (void*)&g0000, (void*)&g0210);

/* (er_quarter) (0 9.2824) (1 11.6408) (2 9.12233) (3 9.37757) (4 11.2154) */
DEF_STATIC_CONST_VAL_CONS(g0214, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0213, (void*)&g0006, (void*)&g0214);
DEF_STATIC_CONST_VAL_CONS(g0212, (void*)&g0004, (void*)&g0213);
DEF_STATIC_CONST_VAL_CONS(g0211, (void*)&g0002, (void*)&g0212);
DEF_STATIC_CONST_VAL_CONS(cl_0068, (void*)&g0000, (void*)&g0211);

/* (t_quarter) (0 9.02435) (1 9.00398) (2 10.126) (3 8.86374) (4 11.0814) */
DEF_STATIC_CONST_VAL_CONS(g0218, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0217, (void*)&g0006, (void*)&g0218);
DEF_STATIC_CONST_VAL_CONS(g0216, (void*)&g0004, (void*)&g0217);
DEF_STATIC_CONST_VAL_CONS(g0215, (void*)&g0002, (void*)&g0216);
DEF_STATIC_CONST_VAL_CONS(cl_0069, (void*)&g0000, (void*)&g0215);

/* (r_quarter) (0 8.96474) (1 8.91445) (2 7.41166) (3 7.94757) (4 9.1476) */
DEF_STATIC_CONST_VAL_CONS(g0222, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0221, (void*)&g0006, (void*)&g0222);
DEF_STATIC_CONST_VAL_CONS(g0220, (void*)&g0004, (void*)&g0221);
DEF_STATIC_CONST_VAL_CONS(g0219, (void*)&g0002, (void*)&g0220);
DEF_STATIC_CONST_VAL_CONS(cl_0070, (void*)&g0000, (void*)&g0219);

/* (ao_quarter) (0 9.40994) (1 8.38505) (2 9.01189) (3 9.2387) (4 10.5159) */
DEF_STATIC_CONST_VAL_CONS(g0226, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0225, (void*)&g0006, (void*)&g0226);
DEF_STATIC_CONST_VAL_CONS(g0224, (void*)&g0004, (void*)&g0225);
DEF_STATIC_CONST_VAL_CONS(g0223, (void*)&g0002, (void*)&g0224);
DEF_STATIC_CONST_VAL_CONS(cl_0071, (void*)&g0000, (void*)&g0223);

/* (w_quarter) (0 8.29835) (1 7.43445) (2 6.93759) (3 8.25315) (4 8.44849) */
DEF_STATIC_CONST_VAL_CONS(g0230, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0229, (void*)&g0006, (void*)&g0230);
DEF_STATIC_CONST_VAL_CONS(g0228, (void*)&g0004, (void*)&g0229);
DEF_STATIC_CONST_VAL_CONS(g0227, (void*)&g0002, (void*)&g0228);
DEF_STATIC_CONST_VAL_CONS(cl_0072, (void*)&g0000, (void*)&g0227);

/* (k_quarter) (0 8.79413) (1 8.55609) (2 7.3411) (3 7.9345) (4 8.03236) */
DEF_STATIC_CONST_VAL_CONS(g0234, (void*)&g0008, 0);
DEF_STATIC_CONST_VAL_CONS(g0233, (void*)&g0006, (void*)&g0234);
DEF_STATIC_CONST_VAL_CONS(g0232, (void*)&g0004, (void*)&g0233);
DEF_STATIC_CONST_VAL_CONS(g0231, (void*)&g0002, (void*)&g0232);
DEF_STATIC_CONST_VAL_CONS(cl_0073, (void*)&g0000, (void*)&g0231);

/* (ax_little) (0 7.02638) (1 8.05693) (2 8.4189) (3 7.42947) (4 7.33171) (5 6.70706) */
DEF_STATIC_CONST_VAL_CONS(g0239, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0238, (void*)&g0008, (void*)&g0239);
DEF_STATIC_CONST_VAL_CONS(g0237, (void*)&g0006, (void*)&g0238);
DEF_STATIC_CONST_VAL_CONS(g0236, (void*)&g0004, (void*)&g0237);
DEF_STATIC_CONST_VAL_CONS(g0235, (void*)&g0002, (void*)&g0236);
DEF_STATIC_CONST_VAL_CONS(cl_0074, (void*)&g0000, (void*)&g0235);

/* (t_little) (0 6.96389) (1 6.87418) (2 9.12427) (3 7.21173) (4 7.89517) (5 6.10585) */
DEF_STATIC_CONST_VAL_CONS(g0244, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0243, (void*)&g0008, (void*)&g0244);
DEF_STATIC_CONST_VAL_CONS(g0242, (void*)&g0006, (void*)&g0243);
DEF_STATIC_CONST_VAL_CONS(g0241, (void*)&g0004, (void*)&g0242);
DEF_STATIC_CONST_VAL_CONS(g0240, (void*)&g0002, (void*)&g0241);
DEF_STATIC_CONST_VAL_CONS(cl_0075, (void*)&g0000, (void*)&g0240);

/* (ih_little) (0 9.016) (1 8.24892) (2 7.89524) (3 6.39528) (4 8.38779) (5 9.01802) */
DEF_STATIC_CONST_VAL_CONS(g0249, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0248, (void*)&g0008, (void*)&g0249);
DEF_STATIC_CONST_VAL_CONS(g0247, (void*)&g0006, (void*)&g0248);
DEF_STATIC_CONST_VAL_CONS(g0246, (void*)&g0004, (void*)&g0247);
DEF_STATIC_CONST_VAL_CONS(g0245, (void*)&g0002, (void*)&g0246);
DEF_STATIC_CONST_VAL_CONS(cl_0076, (void*)&g0000, (void*)&g0245);

/* (l_little) (0 8.16729) (1 10.2509) (2 8.95973) (3 10.5432) (4 9.13675) (5 8.7343) (6 8.90477) (7 7.80223) (8 7.25549) (9 10.8563) (10 9.13523) (11 12.3908) */
DEF_STATIC_CONST_VAL_CONS(g0260, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0259, (void*)&g0074, (void*)&g0260);
DEF_STATIC_CONST_VAL_CONS(g0258, (void*)&g0047, (void*)&g0259);
DEF_STATIC_CONST_VAL_CONS(g0257, (void*)&g0045, (void*)&g0258);
DEF_STATIC_CONST_VAL_CONS(g0256, (void*)&g0043, (void*)&g0257);
DEF_STATIC_CONST_VAL_CONS(g0255, (void*)&g0041, (void*)&g0256);
DEF_STATIC_CONST_VAL_CONS(g0254, (void*)&g0010, (void*)&g0255);
DEF_STATIC_CONST_VAL_CONS(g0253, (void*)&g0008, (void*)&g0254);
DEF_STATIC_CONST_VAL_CONS(g0252, (void*)&g0006, (void*)&g0253);
DEF_STATIC_CONST_VAL_CONS(g0251, (void*)&g0004, (void*)&g0252);
DEF_STATIC_CONST_VAL_CONS(g0250, (void*)&g0002, (void*)&g0251);
DEF_STATIC_CONST_VAL_CONS(cl_0077, (void*)&g0000, (void*)&g0250);

/* (ax_a) (0 11.2691) (1 9.7276) (2 11.5599) (3 11.3206) (4 10.4004) (5 10.158) */
DEF_STATIC_CONST_VAL_CONS(g0265, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0264, (void*)&g0008, (void*)&g0265);
DEF_STATIC_CONST_VAL_CONS(g0263, (void*)&g0006, (void*)&g0264);
DEF_STATIC_CONST_VAL_CONS(g0262, (void*)&g0004, (void*)&g0263);
DEF_STATIC_CONST_VAL_CONS(g0261, (void*)&g0002, (void*)&g0262);
DEF_STATIC_CONST_VAL_CONS(cl_0078, (void*)&g0000, (void*)&g0261);

/* (pau_uw) (0 5.94988) (1 5.94988) */
DEF_STATIC_CONST_VAL_CONS(g0266, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0079, (void*)&g0000, (void*)&g0266);

/* (uw_two) (0 6.18712) (1 6.18712) */
DEF_STATIC_CONST_VAL_CONS(g0267, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0080, (void*)&g0000, (void*)&g0267);

/* (t_two) (0 9.30463) (1 9.30463) */
DEF_STATIC_CONST_VAL_CONS(g0268, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0081, (void*)&g0000, (void*)&g0268);

/* (n_ten) (0 8.6577) (1 8.31046) (2 7.70886) (3 12.3898) (4 8.06833) (5 8.8574) */
DEF_STATIC_CONST_VAL_CONS(g0273, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0272, (void*)&g0008, (void*)&g0273);
DEF_STATIC_CONST_VAL_CONS(g0271, (void*)&g0006, (void*)&g0272);
DEF_STATIC_CONST_VAL_CONS(g0270, (void*)&g0004, (void*)&g0271);
DEF_STATIC_CONST_VAL_CONS(g0269, (void*)&g0002, (void*)&g0270);
DEF_STATIC_CONST_VAL_CONS(cl_0082, (void*)&g0000, (void*)&g0269);

/* (eh_ten) (0 10.9998) (1 9.8859) (2 9.521) (3 9.80632) (4 10.5116) (5 10.8828) */
DEF_STATIC_CONST_VAL_CONS(g0278, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0277, (void*)&g0008, (void*)&g0278);
DEF_STATIC_CONST_VAL_CONS(g0276, (void*)&g0006, (void*)&g0277);
DEF_STATIC_CONST_VAL_CONS(g0275, (void*)&g0004, (void*)&g0276);
DEF_STATIC_CONST_VAL_CONS(g0274, (void*)&g0002, (void*)&g0275);
DEF_STATIC_CONST_VAL_CONS(cl_0083, (void*)&g0000, (void*)&g0274);

/* (t_ten) (0 10.4455) (1 9.66809) (2 9.54494) (3 10.6256) (4 10.4191) (5 9.51983) */
DEF_STATIC_CONST_VAL_CONS(g0283, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0282, (void*)&g0008, (void*)&g0283);
DEF_STATIC_CONST_VAL_CONS(g0281, (void*)&g0006, (void*)&g0282);
DEF_STATIC_CONST_VAL_CONS(g0280, (void*)&g0004, (void*)&g0281);
DEF_STATIC_CONST_VAL_CONS(g0279, (void*)&g0002, (void*)&g0280);
DEF_STATIC_CONST_VAL_CONS(cl_0084, (void*)&g0000, (void*)&g0279);

/* (er_after) (0 7.5581) (1 10.5157) (2 10.6869) (3 8.40734) (4 8.69363) (5 12.1358) (6 9.58039) (7 7.78057) (8 12.1584) (9 10.7675) (10 8.80554) (11 11.0766) */
DEF_STATIC_CONST_VAL_CONS(g0294, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0293, (void*)&g0074, (void*)&g0294);
DEF_STATIC_CONST_VAL_CONS(g0292, (void*)&g0047, (void*)&g0293);
DEF_STATIC_CONST_VAL_CONS(g0291, (void*)&g0045, (void*)&g0292);
DEF_STATIC_CONST_VAL_CONS(g0290, (void*)&g0043, (void*)&g0291);
DEF_STATIC_CONST_VAL_CONS(g0289, (void*)&g0041, (void*)&g0290);
DEF_STATIC_CONST_VAL_CONS(g0288, (void*)&g0010, (void*)&g0289);
DEF_STATIC_CONST_VAL_CONS(g0287, (void*)&g0008, (void*)&g0288);
DEF_STATIC_CONST_VAL_CONS(g0286, (void*)&g0006, (void*)&g0287);
DEF_STATIC_CONST_VAL_CONS(g0285, (void*)&g0004, (void*)&g0286);
DEF_STATIC_CONST_VAL_CONS(g0284, (void*)&g0002, (void*)&g0285);
DEF_STATIC_CONST_VAL_CONS(cl_0085, (void*)&g0000, (void*)&g0284);

/* (t_after) (0 10.0087) (1 8.37187) (2 10.2571) (3 8.79786) (4 8.7226) (5 11.5054) (6 9.98903) (7 9.41387) (8 9.95232) (9 9.60776) (10 9.18826) (11 9.75738) */
DEF_STATIC_CONST_VAL_CONS(g0305, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0304, (void*)&g0074, (void*)&g0305);
DEF_STATIC_CONST_VAL_CONS(g0303, (void*)&g0047, (void*)&g0304);
DEF_STATIC_CONST_VAL_CONS(g0302, (void*)&g0045, (void*)&g0303);
DEF_STATIC_CONST_VAL_CONS(g0301, (void*)&g0043, (void*)&g0302);
DEF_STATIC_CONST_VAL_CONS(g0300, (void*)&g0041, (void*)&g0301);
DEF_STATIC_CONST_VAL_CONS(g0299, (void*)&g0010, (void*)&g0300);
DEF_STATIC_CONST_VAL_CONS(g0298, (void*)&g0008, (void*)&g0299);
DEF_STATIC_CONST_VAL_CONS(g0297, (void*)&g0006, (void*)&g0298);
DEF_STATIC_CONST_VAL_CONS(g0296, (void*)&g0004, (void*)&g0297);
DEF_STATIC_CONST_VAL_CONS(g0295, (void*)&g0002, (void*)&g0296);
DEF_STATIC_CONST_VAL_CONS(cl_0086, (void*)&g0000, (void*)&g0295);

/* (f_after) (0 8.34115) (1 6.87779) (2 7.85803) (3 7.01223) (4 9.83223) (5 7.95968) (6 8.09437) (7 10.2671) (8 7.87164) (9 7.45198) (10 9.63726) (11 9.29734) */
DEF_STATIC_CONST_VAL_CONS(g0316, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0315, (void*)&g0074, (void*)&g0316);
DEF_STATIC_CONST_VAL_CONS(g0314, (void*)&g0047, (void*)&g0315);
DEF_STATIC_CONST_VAL_CONS(g0313, (void*)&g0045, (void*)&g0314);
DEF_STATIC_CONST_VAL_CONS(g0312, (void*)&g0043, (void*)&g0313);
DEF_STATIC_CONST_VAL_CONS(g0311, (void*)&g0041, (void*)&g0312);
DEF_STATIC_CONST_VAL_CONS(g0310, (void*)&g0010, (void*)&g0311);
DEF_STATIC_CONST_VAL_CONS(g0309, (void*)&g0008, (void*)&g0310);
DEF_STATIC_CONST_VAL_CONS(g0308, (void*)&g0006, (void*)&g0309);
DEF_STATIC_CONST_VAL_CONS(g0307, (void*)&g0004, (void*)&g0308);
DEF_STATIC_CONST_VAL_CONS(g0306, (void*)&g0002, (void*)&g0307);
DEF_STATIC_CONST_VAL_CONS(cl_0087, (void*)&g0000, (void*)&g0306);

/* (ae_after) (0 6.07619) (1 8.17233) (2 7.65668) (3 7.56076) (4 8.90812) (5 10.614) (6 7.55187) (7 9.24287) (8 7.55773) (9 7.77655) (10 9.45284) (11 8.3274) */
DEF_STATIC_CONST_VAL_CONS(g0327, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0326, (void*)&g0074, (void*)&g0327);
DEF_STATIC_CONST_VAL_CONS(g0325, (void*)&g0047, (void*)&g0326);
DEF_STATIC_CONST_VAL_CONS(g0324, (void*)&g0045, (void*)&g0325);
DEF_STATIC_CONST_VAL_CONS(g0323, (void*)&g0043, (void*)&g0324);
DEF_STATIC_CONST_VAL_CONS(g0322, (void*)&g0041, (void*)&g0323);
DEF_STATIC_CONST_VAL_CONS(g0321, (void*)&g0010, (void*)&g0322);
DEF_STATIC_CONST_VAL_CONS(g0320, (void*)&g0008, (void*)&g0321);
DEF_STATIC_CONST_VAL_CONS(g0319, (void*)&g0006, (void*)&g0320);
DEF_STATIC_CONST_VAL_CONS(g0318, (void*)&g0004, (void*)&g0319);
DEF_STATIC_CONST_VAL_CONS(g0317, (void*)&g0002, (void*)&g0318);
DEF_STATIC_CONST_VAL_CONS(cl_0088, (void*)&g0000, (void*)&g0317);

/* (t_just) (0 6.5191) (1 7.25462) (2 7.30561) (3 8.44849) (4 7.23904) (5 8.97738) */
DEF_STATIC_CONST_VAL_CONS(g0332, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0331, (void*)&g0008, (void*)&g0332);
DEF_STATIC_CONST_VAL_CONS(g0330, (void*)&g0006, (void*)&g0331);
DEF_STATIC_CONST_VAL_CONS(g0329, (void*)&g0004, (void*)&g0330);
DEF_STATIC_CONST_VAL_CONS(g0328, (void*)&g0002, (void*)&g0329);
DEF_STATIC_CONST_VAL_CONS(cl_0089, (void*)&g0000, (void*)&g0328);

/* (s_just) (0 5.77644) (1 6.45956) (2 7.29168) (3 7.38843) (4 6.13132) (5 8.24239) */
DEF_STATIC_CONST_VAL_CONS(g0337, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0336, (void*)&g0008, (void*)&g0337);
DEF_STATIC_CONST_VAL_CONS(g0335, (void*)&g0006, (void*)&g0336);
DEF_STATIC_CONST_VAL_CONS(g0334, (void*)&g0004, (void*)&g0335);
DEF_STATIC_CONST_VAL_CONS(g0333, (void*)&g0002, (void*)&g0334);
DEF_STATIC_CONST_VAL_CONS(cl_0090, (void*)&g0000, (void*)&g0333);

/* (ah_just) (0 5.78936) (1 6.79455) (2 6.10054) (3 7.03537) (4 6.99038) (5 8.95832) */
DEF_STATIC_CONST_VAL_CONS(g0342, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0341, (void*)&g0008, (void*)&g0342);
DEF_STATIC_CONST_VAL_CONS(g0340, (void*)&g0006, (void*)&g0341);
DEF_STATIC_CONST_VAL_CONS(g0339, (void*)&g0004, (void*)&g0340);
DEF_STATIC_CONST_VAL_CONS(g0338, (void*)&g0002, (void*)&g0339);
DEF_STATIC_CONST_VAL_CONS(cl_0091, (void*)&g0000, (void*)&g0338);

/* (jh_just) (0 10.7724) (1 11.6118) (2 10.6952) (3 9.2492) (4 9.76437) (5 10.6337) */
DEF_STATIC_CONST_VAL_CONS(g0347, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0346, (void*)&g0008, (void*)&g0347);
DEF_STATIC_CONST_VAL_CONS(g0345, (void*)&g0006, (void*)&g0346);
DEF_STATIC_CONST_VAL_CONS(g0344, (void*)&g0004, (void*)&g0345);
DEF_STATIC_CONST_VAL_CONS(g0343, (void*)&g0002, (void*)&g0344);
DEF_STATIC_CONST_VAL_CONS(cl_0092, (void*)&g0000, (void*)&g0343);

/* (pau_ng) (0 12.335) (1 11.5279) (2 10.3617) (3 10.6784) (4 11.0069) (5 9.63073) (6 10.9008) (7 8.66475) (8 12.9018) (9 13.8889) (10 9.97628) (11 9.84454) (12 9.41305) (13 8.52804) (14 11.4062) (15 11.9502) (16 9.57321) */
DEF_STATIC_CONST_VAL_FLOAT(g0364,16);
DEF_STATIC_CONST_VAL_CONS(g0363, (void*)&g0364, 0);
DEF_STATIC_CONST_VAL_CONS(g0362, (void*)&g0176, (void*)&g0363);
DEF_STATIC_CONST_VAL_CONS(g0361, (void*)&g0174, (void*)&g0362);
DEF_STATIC_CONST_VAL_CONS(g0360, (void*)&g0172, (void*)&g0361);
DEF_STATIC_CONST_VAL_CONS(g0359, (void*)&g0170, (void*)&g0360);
DEF_STATIC_CONST_VAL_CONS(g0358, (void*)&g0168, (void*)&g0359);
DEF_STATIC_CONST_VAL_CONS(g0357, (void*)&g0074, (void*)&g0358);
DEF_STATIC_CONST_VAL_CONS(g0356, (void*)&g0047, (void*)&g0357);
DEF_STATIC_CONST_VAL_CONS(g0355, (void*)&g0045, (void*)&g0356);
DEF_STATIC_CONST_VAL_CONS(g0354, (void*)&g0043, (void*)&g0355);
DEF_STATIC_CONST_VAL_CONS(g0353, (void*)&g0041, (void*)&g0354);
DEF_STATIC_CONST_VAL_CONS(g0352, (void*)&g0010, (void*)&g0353);
DEF_STATIC_CONST_VAL_CONS(g0351, (void*)&g0008, (void*)&g0352);
DEF_STATIC_CONST_VAL_CONS(g0350, (void*)&g0006, (void*)&g0351);
DEF_STATIC_CONST_VAL_CONS(g0349, (void*)&g0004, (void*)&g0350);
DEF_STATIC_CONST_VAL_CONS(g0348, (void*)&g0002, (void*)&g0349);
DEF_STATIC_CONST_VAL_CONS(cl_0093, (void*)&g0000, (void*)&g0348);

/* (ng_morning) (0 6.74852) (1 7.21024) (2 6.23083) (3 8.46198) (4 5.69702) (5 7.17368) (6 6.4292) (7 6.41749) (8 5.43423) (9 6.01875) (10 7.55646) */
DEF_STATIC_CONST_VAL_CONS(g0374, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0373, (void*)&g0047, (void*)&g0374);
DEF_STATIC_CONST_VAL_CONS(g0372, (void*)&g0045, (void*)&g0373);
DEF_STATIC_CONST_VAL_CONS(g0371, (void*)&g0043, (void*)&g0372);
DEF_STATIC_CONST_VAL_CONS(g0370, (void*)&g0041, (void*)&g0371);
DEF_STATIC_CONST_VAL_CONS(g0369, (void*)&g0010, (void*)&g0370);
DEF_STATIC_CONST_VAL_CONS(g0368, (void*)&g0008, (void*)&g0369);
DEF_STATIC_CONST_VAL_CONS(g0367, (void*)&g0006, (void*)&g0368);
DEF_STATIC_CONST_VAL_CONS(g0366, (void*)&g0004, (void*)&g0367);
DEF_STATIC_CONST_VAL_CONS(g0365, (void*)&g0002, (void*)&g0366);
DEF_STATIC_CONST_VAL_CONS(cl_0094, (void*)&g0000, (void*)&g0365);

/* (ih_morning) (0 5.97978) (1 7.71078) (2 6.04651) (3 8.17901) (4 5.82668) (5 5.5846) (6 6.34902) (7 6.29891) (8 4.78199) (9 5.5202) (10 6.18632) */
DEF_STATIC_CONST_VAL_CONS(g0384, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0383, (void*)&g0047, (void*)&g0384);
DEF_STATIC_CONST_VAL_CONS(g0382, (void*)&g0045, (void*)&g0383);
DEF_STATIC_CONST_VAL_CONS(g0381, (void*)&g0043, (void*)&g0382);
DEF_STATIC_CONST_VAL_CONS(g0380, (void*)&g0041, (void*)&g0381);
DEF_STATIC_CONST_VAL_CONS(g0379, (void*)&g0010, (void*)&g0380);
DEF_STATIC_CONST_VAL_CONS(g0378, (void*)&g0008, (void*)&g0379);
DEF_STATIC_CONST_VAL_CONS(g0377, (void*)&g0006, (void*)&g0378);
DEF_STATIC_CONST_VAL_CONS(g0376, (void*)&g0004, (void*)&g0377);
DEF_STATIC_CONST_VAL_CONS(g0375, (void*)&g0002, (void*)&g0376);
DEF_STATIC_CONST_VAL_CONS(cl_0095, (void*)&g0000, (void*)&g0375);

/* (n_morning) (0 10.7601) (1 6.39302) (2 5.94653) (3 6.60196) (4 6.70506) (5 7.32398) (6 6.71157) (7 6.28733) (8 6.19679) (9 9.40832) (10 7.11143) */
DEF_STATIC_CONST_VAL_CONS(g0394, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0393, (void*)&g0047, (void*)&g0394);
DEF_STATIC_CONST_VAL_CONS(g0392, (void*)&g0045, (void*)&g0393);
DEF_STATIC_CONST_VAL_CONS(g0391, (void*)&g0043, (void*)&g0392);
DEF_STATIC_CONST_VAL_CONS(g0390, (void*)&g0041, (void*)&g0391);
DEF_STATIC_CONST_VAL_CONS(g0389, (void*)&g0010, (void*)&g0390);
DEF_STATIC_CONST_VAL_CONS(g0388, (void*)&g0008, (void*)&g0389);
DEF_STATIC_CONST_VAL_CONS(g0387, (void*)&g0006, (void*)&g0388);
DEF_STATIC_CONST_VAL_CONS(g0386, (void*)&g0004, (void*)&g0387);
DEF_STATIC_CONST_VAL_CONS(g0385, (void*)&g0002, (void*)&g0386);
DEF_STATIC_CONST_VAL_CONS(cl_0096, (void*)&g0000, (void*)&g0385);

/* (r_morning) (0 6.6657) (1 3.84972) (2 3.719) (3 4.77994) (4 3.9998) (5 5.35225) (6 4.87514) (7 4.10902) (8 6.17771) (9 4.80941) (10 4.84036) */
DEF_STATIC_CONST_VAL_CONS(g0404, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0403, (void*)&g0047, (void*)&g0404);
DEF_STATIC_CONST_VAL_CONS(g0402, (void*)&g0045, (void*)&g0403);
DEF_STATIC_CONST_VAL_CONS(g0401, (void*)&g0043, (void*)&g0402);
DEF_STATIC_CONST_VAL_CONS(g0400, (void*)&g0041, (void*)&g0401);
DEF_STATIC_CONST_VAL_CONS(g0399, (void*)&g0010, (void*)&g0400);
DEF_STATIC_CONST_VAL_CONS(g0398, (void*)&g0008, (void*)&g0399);
DEF_STATIC_CONST_VAL_CONS(g0397, (void*)&g0006, (void*)&g0398);
DEF_STATIC_CONST_VAL_CONS(g0396, (void*)&g0004, (void*)&g0397);
DEF_STATIC_CONST_VAL_CONS(g0395, (void*)&g0002, (void*)&g0396);
DEF_STATIC_CONST_VAL_CONS(cl_0097, (void*)&g0000, (void*)&g0395);

/* (ao_morning) (0 6.58786) (1 4.34944) (2 4.40433) (3 5.77237) (4 4.36693) (5 5.73935) (6 6.10682) (7 5.42014) (8 5.72969) (9 4.8986) (10 5.75882) */
DEF_STATIC_CONST_VAL_CONS(g0414, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0413, (void*)&g0047, (void*)&g0414);
DEF_STATIC_CONST_VAL_CONS(g0412, (void*)&g0045, (void*)&g0413);
DEF_STATIC_CONST_VAL_CONS(g0411, (void*)&g0043, (void*)&g0412);
DEF_STATIC_CONST_VAL_CONS(g0410, (void*)&g0041, (void*)&g0411);
DEF_STATIC_CONST_VAL_CONS(g0409, (void*)&g0010, (void*)&g0410);
DEF_STATIC_CONST_VAL_CONS(g0408, (void*)&g0008, (void*)&g0409);
DEF_STATIC_CONST_VAL_CONS(g0407, (void*)&g0006, (void*)&g0408);
DEF_STATIC_CONST_VAL_CONS(g0406, (void*)&g0004, (void*)&g0407);
DEF_STATIC_CONST_VAL_CONS(g0405, (void*)&g0002, (void*)&g0406);
DEF_STATIC_CONST_VAL_CONS(cl_0098, (void*)&g0000, (void*)&g0405);

/* (m_morning) (0 8.61755) (1 7.43752) (2 6.32485) (3 7.32379) (4 7.78161) (5 10.1622) (6 9.06246) (7 6.64053) (8 7.4476) (9 7.27182) (10 8.9303) */
DEF_STATIC_CONST_VAL_CONS(g0424, (void*)&g0074, 0);
DEF_STATIC_CONST_VAL_CONS(g0423, (void*)&g0047, (void*)&g0424);
DEF_STATIC_CONST_VAL_CONS(g0422, (void*)&g0045, (void*)&g0423);
DEF_STATIC_CONST_VAL_CONS(g0421, (void*)&g0043, (void*)&g0422);
DEF_STATIC_CONST_VAL_CONS(g0420, (void*)&g0041, (void*)&g0421);
DEF_STATIC_CONST_VAL_CONS(g0419, (void*)&g0010, (void*)&g0420);
DEF_STATIC_CONST_VAL_CONS(g0418, (void*)&g0008, (void*)&g0419);
DEF_STATIC_CONST_VAL_CONS(g0417, (void*)&g0006, (void*)&g0418);
DEF_STATIC_CONST_VAL_CONS(g0416, (void*)&g0004, (void*)&g0417);
DEF_STATIC_CONST_VAL_CONS(g0415, (void*)&g0002, (void*)&g0416);
DEF_STATIC_CONST_VAL_CONS(cl_0099, (void*)&g0000, (void*)&g0415);

/* (n_in) (0 7.31354) (1 8.11399) (2 7.97047) (3 8.75865) (4 8.75692) (5 9.52462) (6 8.08024) (7 8.46289) (8 7.545) (9 7.67695) (10 7.10608) (11 7.14942) (12 7.63519) (13 6.58601) (14 8.01654) (15 7.14019) (16 7.9871) (17 9.37175) (18 7.5466) (19 9.6793) */
DEF_STATIC_CONST_VAL_FLOAT(g0442,17);
DEF_STATIC_CONST_VAL_FLOAT(g0444,18);
DEF_STATIC_CONST_VAL_FLOAT(g0446,19);
DEF_STATIC_CONST_VAL_CONS(g0445, (void*)&g0446, 0);
DEF_STATIC_CONST_VAL_CONS(g0443, (void*)&g0444, (void*)&g0445);
DEF_STATIC_CONST_VAL_CONS(g0441, (void*)&g0442, (void*)&g0443);
DEF_STATIC_CONST_VAL_CONS(g0440, (void*)&g0364, (void*)&g0441);
DEF_STATIC_CONST_VAL_CONS(g0439, (void*)&g0176, (void*)&g0440);
DEF_STATIC_CONST_VAL_CONS(g0438, (void*)&g0174, (void*)&g0439);
DEF_STATIC_CONST_VAL_CONS(g0437, (void*)&g0172, (void*)&g0438);
DEF_STATIC_CONST_VAL_CONS(g0436, (void*)&g0170, (void*)&g0437);
DEF_STATIC_CONST_VAL_CONS(g0435, (void*)&g0168, (void*)&g0436);
DEF_STATIC_CONST_VAL_CONS(g0434, (void*)&g0074, (void*)&g0435);
DEF_STATIC_CONST_VAL_CONS(g0433, (void*)&g0047, (void*)&g0434);
DEF_STATIC_CONST_VAL_CONS(g0432, (void*)&g0045, (void*)&g0433);
DEF_STATIC_CONST_VAL_CONS(g0431, (void*)&g0043, (void*)&g0432);
DEF_STATIC_CONST_VAL_CONS(g0430, (void*)&g0041, (void*)&g0431);
DEF_STATIC_CONST_VAL_CONS(g0429, (void*)&g0010, (void*)&g0430);
DEF_STATIC_CONST_VAL_CONS(g0428, (void*)&g0008, (void*)&g0429);
DEF_STATIC_CONST_VAL_CONS(g0427, (void*)&g0006, (void*)&g0428);
DEF_STATIC_CONST_VAL_CONS(g0426, (void*)&g0004, (void*)&g0427);
DEF_STATIC_CONST_VAL_CONS(g0425, (void*)&g0002, (void*)&g0426);
DEF_STATIC_CONST_VAL_CONS(cl_0100, (void*)&g0000, (void*)&g0425);

/* (ih_in) (0 8.60441) (1 8.1716) (2 7.87597) (3 8.54923) (5 9.96083) (6 9.02551) (8 8.88095) (9 8.1798) (10 8.99375) (11 8.89165) (12 8.34372) (13 9.17934) (14 8.29811) (15 9.44539) (16 8.34352) (17 7.74286) (18 7.55679) (19 8.21984) (20 8.4088) (21 8.562) */
DEF_STATIC_CONST_VAL_FLOAT(g0465,20);
DEF_STATIC_CONST_VAL_FLOAT(g0467,21);
DEF_STATIC_CONST_VAL_CONS(g0466, (void*)&g0467, 0);
DEF_STATIC_CONST_VAL_CONS(g0464, (void*)&g0465, (void*)&g0466);
DEF_STATIC_CONST_VAL_CONS(g0463, (void*)&g0446, (void*)&g0464);
DEF_STATIC_CONST_VAL_CONS(g0462, (void*)&g0444, (void*)&g0463);
DEF_STATIC_CONST_VAL_CONS(g0461, (void*)&g0442, (void*)&g0462);
DEF_STATIC_CONST_VAL_CONS(g0460, (void*)&g0364, (void*)&g0461);
DEF_STATIC_CONST_VAL_CONS(g0459, (void*)&g0176, (void*)&g0460);
DEF_STATIC_CONST_VAL_CONS(g0458, (void*)&g0174, (void*)&g0459);
DEF_STATIC_CONST_VAL_CONS(g0457, (void*)&g0172, (void*)&g0458);
DEF_STATIC_CONST_VAL_CONS(g0456, (void*)&g0170, (void*)&g0457);
DEF_STATIC_CONST_VAL_CONS(g0455, (void*)&g0168, (void*)&g0456);
DEF_STATIC_CONST_VAL_CONS(g0454, (void*)&g0074, (void*)&g0455);
DEF_STATIC_CONST_VAL_CONS(g0453, (void*)&g0047, (void*)&g0454);
DEF_STATIC_CONST_VAL_CONS(g0452, (void*)&g0045, (void*)&g0453);
DEF_STATIC_CONST_VAL_CONS(g0451, (void*)&g0041, (void*)&g0452);
DEF_STATIC_CONST_VAL_CONS(g0450, (void*)&g0010, (void*)&g0451);
DEF_STATIC_CONST_VAL_CONS(g0449, (void*)&g0006, (void*)&g0450);
DEF_STATIC_CONST_VAL_CONS(g0448, (void*)&g0004, (void*)&g0449);
DEF_STATIC_CONST_VAL_CONS(g0447, (void*)&g0002, (void*)&g0448);
DEF_STATIC_CONST_VAL_CONS(cl_0101, (void*)&g0000, (void*)&g0447);

/* (pau_n) (0 10.2016) (1 10.1556) (2 10.7041) (3 9.50936) (4 8.44643) (5 8.20734) (6 8.02458) (7 7.74951) (8 7.33068) (9 9.89511) (10 8.72595) (11 9.54803) (12 8.81863) (13 10.2655) (14 9.82624) */
DEF_STATIC_CONST_VAL_CONS(g0481, (void*)&g0174, 0);
DEF_STATIC_CONST_VAL_CONS(g0480, (void*)&g0172, (void*)&g0481);
DEF_STATIC_CONST_VAL_CONS(g0479, (void*)&g0170, (void*)&g0480);
DEF_STATIC_CONST_VAL_CONS(g0478, (void*)&g0168, (void*)&g0479);
DEF_STATIC_CONST_VAL_CONS(g0477, (void*)&g0074, (void*)&g0478);
DEF_STATIC_CONST_VAL_CONS(g0476, (void*)&g0047, (void*)&g0477);
DEF_STATIC_CONST_VAL_CONS(g0475, (void*)&g0045, (void*)&g0476);
DEF_STATIC_CONST_VAL_CONS(g0474, (void*)&g0043, (void*)&g0475);
DEF_STATIC_CONST_VAL_CONS(g0473, (void*)&g0041, (void*)&g0474);
DEF_STATIC_CONST_VAL_CONS(g0472, (void*)&g0010, (void*)&g0473);
DEF_STATIC_CONST_VAL_CONS(g0471, (void*)&g0008, (void*)&g0472);
DEF_STATIC_CONST_VAL_CONS(g0470, (void*)&g0006, (void*)&g0471);
DEF_STATIC_CONST_VAL_CONS(g0469, (void*)&g0004, (void*)&g0470);
DEF_STATIC_CONST_VAL_CONS(g0468, (void*)&g0002, (void*)&g0469);
DEF_STATIC_CONST_VAL_CONS(cl_0102, (void*)&g0000, (void*)&g0468);

/* (n_one) (0 6.02352) (1 6.02352) */
DEF_STATIC_CONST_VAL_CONS(g0482, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0103, (void*)&g0000, (void*)&g0482);

/* (ah_one) (0 5.27766) (1 5.27766) */
DEF_STATIC_CONST_VAL_CONS(g0483, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0104, (void*)&g0000, (void*)&g0483);

/* (w_one) (0 9.24668) (1 9.24668) */
DEF_STATIC_CONST_VAL_CONS(g0484, (void*)&g0002, 0);
DEF_STATIC_CONST_VAL_CONS(cl_0105, (void*)&g0000, (void*)&g0484);

/* (t_past) (0 10.2058) (1 10.1864) (2 9.31537) (3 11.5408) (4 12.342) (5 11.5115) (6 11.7525) (7 9.03558) (8 10.3321) (9 10.4845) (10 11.6738) (11 12.9206) */
DEF_STATIC_CONST_VAL_CONS(g0495, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0494, (void*)&g0074, (void*)&g0495);
DEF_STATIC_CONST_VAL_CONS(g0493, (void*)&g0047, (void*)&g0494);
DEF_STATIC_CONST_VAL_CONS(g0492, (void*)&g0045, (void*)&g0493);
DEF_STATIC_CONST_VAL_CONS(g0491, (void*)&g0043, (void*)&g0492);
DEF_STATIC_CONST_VAL_CONS(g0490, (void*)&g0041, (void*)&g0491);
DEF_STATIC_CONST_VAL_CONS(g0489, (void*)&g0010, (void*)&g0490);
DEF_STATIC_CONST_VAL_CONS(g0488, (void*)&g0008, (void*)&g0489);
DEF_STATIC_CONST_VAL_CONS(g0487, (void*)&g0006, (void*)&g0488);
DEF_STATIC_CONST_VAL_CONS(g0486, (void*)&g0004, (void*)&g0487);
DEF_STATIC_CONST_VAL_CONS(g0485, (void*)&g0002, (void*)&g0486);
DEF_STATIC_CONST_VAL_CONS(cl_0106, (void*)&g0000, (void*)&g0485);

/* (s_past) (0 6.02326) (1 8.8993) (2 6.92591) (3 7.15267) (4 6.02019) (5 7.33639) (6 6.28627) (7 7.43025) (8 6.96886) (9 7.94986) (10 7.77248) (11 10.2246) */
DEF_STATIC_CONST_VAL_CONS(g0506, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0505, (void*)&g0074, (void*)&g0506);
DEF_STATIC_CONST_VAL_CONS(g0504, (void*)&g0047, (void*)&g0505);
DEF_STATIC_CONST_VAL_CONS(g0503, (void*)&g0045, (void*)&g0504);
DEF_STATIC_CONST_VAL_CONS(g0502, (void*)&g0043, (void*)&g0503);
DEF_STATIC_CONST_VAL_CONS(g0501, (void*)&g0041, (void*)&g0502);
DEF_STATIC_CONST_VAL_CONS(g0500, (void*)&g0010, (void*)&g0501);
DEF_STATIC_CONST_VAL_CONS(g0499, (void*)&g0008, (void*)&g0500);
DEF_STATIC_CONST_VAL_CONS(g0498, (void*)&g0006, (void*)&g0499);
DEF_STATIC_CONST_VAL_CONS(g0497, (void*)&g0004, (void*)&g0498);
DEF_STATIC_CONST_VAL_CONS(g0496, (void*)&g0002, (void*)&g0497);
DEF_STATIC_CONST_VAL_CONS(cl_0107, (void*)&g0000, (void*)&g0496);

/* (ae_past) (0 6.10269) (1 8.59185) (2 6.58326) (3 8.00261) (4 7.92582) (5 6.67715) (6 7.08811) (7 7.50712) (8 6.67385) (9 7.74836) (10 6.35424) (11 8.49675) */
DEF_STATIC_CONST_VAL_CONS(g0517, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0516, (void*)&g0074, (void*)&g0517);
DEF_STATIC_CONST_VAL_CONS(g0515, (void*)&g0047, (void*)&g0516);
DEF_STATIC_CONST_VAL_CONS(g0514, (void*)&g0045, (void*)&g0515);
DEF_STATIC_CONST_VAL_CONS(g0513, (void*)&g0043, (void*)&g0514);
DEF_STATIC_CONST_VAL_CONS(g0512, (void*)&g0041, (void*)&g0513);
DEF_STATIC_CONST_VAL_CONS(g0511, (void*)&g0010, (void*)&g0512);
DEF_STATIC_CONST_VAL_CONS(g0510, (void*)&g0008, (void*)&g0511);
DEF_STATIC_CONST_VAL_CONS(g0509, (void*)&g0006, (void*)&g0510);
DEF_STATIC_CONST_VAL_CONS(g0508, (void*)&g0004, (void*)&g0509);
DEF_STATIC_CONST_VAL_CONS(g0507, (void*)&g0002, (void*)&g0508);
DEF_STATIC_CONST_VAL_CONS(cl_0108, (void*)&g0000, (void*)&g0507);

/* (p_past) (0 8.1079) (1 11.4177) (2 7.89808) (3 12.2678) (4 8.51154) (5 9.14013) (6 10.7255) (7 8.04891) (8 10.4227) (9 9.42444) (10 10.1213) (11 8.65746) */
DEF_STATIC_CONST_VAL_CONS(g0528, (void*)&g0168, 0);
DEF_STATIC_CONST_VAL_CONS(g0527, (void*)&g0074, (void*)&g0528);
DEF_STATIC_CONST_VAL_CONS(g0526, (void*)&g0047, (void*)&g0527);
DEF_STATIC_CONST_VAL_CONS(g0525, (void*)&g0045, (void*)&g0526);
DEF_STATIC_CONST_VAL_CONS(g0524, (void*)&g0043, (void*)&g0525);
DEF_STATIC_CONST_VAL_CONS(g0523, (void*)&g0041, (void*)&g0524);
DEF_STATIC_CONST_VAL_CONS(g0522, (void*)&g0010, (void*)&g0523);
DEF_STATIC_CONST_VAL_CONS(g0521, (void*)&g0008, (void*)&g0522);
DEF_STATIC_CONST_VAL_CONS(g0520, (void*)&g0006, (void*)&g0521);
DEF_STATIC_CONST_VAL_CONS(g0519, (void*)&g0004, (void*)&g0520);
DEF_STATIC_CONST_VAL_CONS(g0518, (void*)&g0002, (void*)&g0519);
DEF_STATIC_CONST_VAL_CONS(cl_0109, (void*)&g0000, (void*)&g0518);

/* (v_five) (0 5.33382) (1 6.4899) (2 10.4445) (3 6.51501) (4 5.32503) (5 5.62064) (6 5.85483) (7 8.89717) (8 5.42282) (9 6.16953) */
DEF_STATIC_CONST_VAL_CONS(g0537, (void*)&g0047, 0);
DEF_STATIC_CONST_VAL_CONS(g0536, (void*)&g0045, (void*)&g0537);
DEF_STATIC_CONST_VAL_CONS(g0535, (void*)&g0043, (void*)&g0536);
DEF_STATIC_CONST_VAL_CONS(g0534, (void*)&g0041, (void*)&g0535);
DEF_STATIC_CONST_VAL_CONS(g0533, (void*)&g0010, (void*)&g0534);
DEF_STATIC_CONST_VAL_CONS(g0532, (void*)&g0008, (void*)&g0533);
DEF_STATIC_CONST_VAL_CONS(g0531, (void*)&g0006, (void*)&g0532);
DEF_STATIC_CONST_VAL_CONS(g0530, (void*)&g0004, (void*)&g0531);
DEF_STATIC_CONST_VAL_CONS(g0529, (void*)&g0002, (void*)&g0530);
DEF_STATIC_CONST_VAL_CONS(cl_0110, (void*)&g0000, (void*)&g0529);

/* (ay_five) (0 6.52488) (1 7.16141) (2 7.27437) (3 5.87845) (4 5.50021) (5 5.83345) (6 5.60545) (7 7.93695) (8 5.78677) (9 6.40392) */
DEF_STATIC_CONST_VAL_CONS(g0546, (void*)&g0047, 0);
DEF_STATIC_CONST_VAL_CONS(g0545, (void*)&g0045, (void*)&g0546);
DEF_STATIC_CONST_VAL_CONS(g0544, (void*)&g0043, (void*)&g0545);
DEF_STATIC_CONST_VAL_CONS(g0543, (void*)&g0041, (void*)&g0544);
DEF_STATIC_CONST_VAL_CONS(g0542, (void*)&g0010, (void*)&g0543);
DEF_STATIC_CONST_VAL_CONS(g0541, (void*)&g0008, (void*)&g0542);
DEF_STATIC_CONST_VAL_CONS(g0540, (void*)&g0006, (void*)&g0541);
DEF_STATIC_CONST_VAL_CONS(g0539, (void*)&g0004, (void*)&g0540);
DEF_STATIC_CONST_VAL_CONS(g0538, (void*)&g0002, (void*)&g0539);
DEF_STATIC_CONST_VAL_CONS(cl_0111, (void*)&g0000, (void*)&g0538);

/* (f_five) (0 9.10168) (1 9.9702) (2 8.1464) (3 8.83553) (4 10.8381) (5 9.19117) (6 8.70017) (7 7.54813) (8 10.7649) (9 8.79196) */
DEF_STATIC_CONST_VAL_CONS(g0555, (void*)&g0047, 0);
DEF_STATIC_CONST_VAL_CONS(g0554, (void*)&g0045, (void*)&g0555);
DEF_STATIC_CONST_VAL_CONS(g0553, (void*)&g0043, (void*)&g0554);
DEF_STATIC_CONST_VAL_CONS(g0552, (void*)&g0041, (void*)&g0553);
DEF_STATIC_CONST_VAL_CONS(g0551, (void*)&g0010, (void*)&g0552);
DEF_STATIC_CONST_VAL_CONS(g0550, (void*)&g0008, (void*)&g0551);
DEF_STATIC_CONST_VAL_CONS(g0549, (void*)&g0006, (void*)&g0550);
DEF_STATIC_CONST_VAL_CONS(g0548, (void*)&g0004, (void*)&g0549);
DEF_STATIC_CONST_VAL_CONS(g0547, (void*)&g0002, (void*)&g0548);
DEF_STATIC_CONST_VAL_CONS(cl_0112, (void*)&g0000, (void*)&g0547);

/* (iy_exactly) (0 6.49898) (1 10.1705) (2 7.34227) (3 8.08977) (4 6.79077) (5 7.90803) */
DEF_STATIC_CONST_VAL_CONS(g0560, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0559, (void*)&g0008, (void*)&g0560);
DEF_STATIC_CONST_VAL_CONS(g0558, (void*)&g0006, (void*)&g0559);
DEF_STATIC_CONST_VAL_CONS(g0557, (void*)&g0004, (void*)&g0558);
DEF_STATIC_CONST_VAL_CONS(g0556, (void*)&g0002, (void*)&g0557);
DEF_STATIC_CONST_VAL_CONS(cl_0113, (void*)&g0000, (void*)&g0556);

/* (l_exactly) (0 6.86639) (1 9.91567) (2 8.93478) (3 10.7028) (4 7.73743) (5 8.62221) */
DEF_STATIC_CONST_VAL_CONS(g0565, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0564, (void*)&g0008, (void*)&g0565);
DEF_STATIC_CONST_VAL_CONS(g0563, (void*)&g0006, (void*)&g0564);
DEF_STATIC_CONST_VAL_CONS(g0562, (void*)&g0004, (void*)&g0563);
DEF_STATIC_CONST_VAL_CONS(g0561, (void*)&g0002, (void*)&g0562);
DEF_STATIC_CONST_VAL_CONS(cl_0114, (void*)&g0000, (void*)&g0561);

/* (t_exactly) (0 8.42766) (1 11.4347) (2 8.31922) (3 11.1396) (4 8.07014) (5 8.51961) */
DEF_STATIC_CONST_VAL_CONS(g0570, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0569, (void*)&g0008, (void*)&g0570);
DEF_STATIC_CONST_VAL_CONS(g0568, (void*)&g0006, (void*)&g0569);
DEF_STATIC_CONST_VAL_CONS(g0567, (void*)&g0004, (void*)&g0568);
DEF_STATIC_CONST_VAL_CONS(g0566, (void*)&g0002, (void*)&g0567);
DEF_STATIC_CONST_VAL_CONS(cl_0115, (void*)&g0000, (void*)&g0566);

/* (k_exactly) (0 9.10047) (1 9.90216) (2 7.86343) (3 8.80127) (4 7.75547) (5 12.2335) */
DEF_STATIC_CONST_VAL_CONS(g0575, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0574, (void*)&g0008, (void*)&g0575);
DEF_STATIC_CONST_VAL_CONS(g0573, (void*)&g0006, (void*)&g0574);
DEF_STATIC_CONST_VAL_CONS(g0572, (void*)&g0004, (void*)&g0573);
DEF_STATIC_CONST_VAL_CONS(g0571, (void*)&g0002, (void*)&g0572);
DEF_STATIC_CONST_VAL_CONS(cl_0116, (void*)&g0000, (void*)&g0571);

/* (ae_exactly) (0 7.55119) (1 8.34421) (2 6.77725) (3 6.81749) (4 6.88789) (5 11.7001) */
DEF_STATIC_CONST_VAL_CONS(g0580, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0579, (void*)&g0008, (void*)&g0580);
DEF_STATIC_CONST_VAL_CONS(g0578, (void*)&g0006, (void*)&g0579);
DEF_STATIC_CONST_VAL_CONS(g0577, (void*)&g0004, (void*)&g0578);
DEF_STATIC_CONST_VAL_CONS(g0576, (void*)&g0002, (void*)&g0577);
DEF_STATIC_CONST_VAL_CONS(cl_0117, (void*)&g0000, (void*)&g0576);

/* (z_exactly) (0 9.02182) (1 10.6029) (2 7.13559) (3 7.64378) (4 9.28159) (5 9.39275) */
DEF_STATIC_CONST_VAL_CONS(g0585, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0584, (void*)&g0008, (void*)&g0585);
DEF_STATIC_CONST_VAL_CONS(g0583, (void*)&g0006, (void*)&g0584);
DEF_STATIC_CONST_VAL_CONS(g0582, (void*)&g0004, (void*)&g0583);
DEF_STATIC_CONST_VAL_CONS(g0581, (void*)&g0002, (void*)&g0582);
DEF_STATIC_CONST_VAL_CONS(cl_0118, (void*)&g0000, (void*)&g0581);

/* (g_exactly) (0 12.9637) (1 8.38637) (2 6.30749) (3 7.95352) (4 8.45975) (5 9.74418) */
DEF_STATIC_CONST_VAL_CONS(g0590, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0589, (void*)&g0008, (void*)&g0590);
DEF_STATIC_CONST_VAL_CONS(g0588, (void*)&g0006, (void*)&g0589);
DEF_STATIC_CONST_VAL_CONS(g0587, (void*)&g0004, (void*)&g0588);
DEF_STATIC_CONST_VAL_CONS(g0586, (void*)&g0002, (void*)&g0587);
DEF_STATIC_CONST_VAL_CONS(cl_0119, (void*)&g0000, (void*)&g0586);

/* (ih_exactly) (0 12.1674) (1 14.4332) (2 11.5669) (3 11.5508) (4 10.2875) (5 12.441) */
DEF_STATIC_CONST_VAL_CONS(g0595, (void*)&g0010, 0);
DEF_STATIC_CONST_VAL_CONS(g0594, (void*)&g0008, (void*)&g0595);
DEF_STATIC_CONST_VAL_CONS(g0593, (void*)&g0006, (void*)&g0594);
DEF_STATIC_CONST_VAL_CONS(g0592, (void*)&g0004, (void*)&g0593);
DEF_STATIC_CONST_VAL_CONS(g0591, (void*)&g0002, (void*)&g0592);
DEF_STATIC_CONST_VAL_CONS(cl_0120, (void*)&g0000, (void*)&g0591);

/* (pau_aw) (0 8.03392) (1 9.27702) (2 9.25591) (4 10.1845) (5 8.63679) (6 7.8999) (7 9.45824) (8 9.77194) (9 8.65198) (10 7.98672) (12 8.65606) (13 9.13818) (14 8.4831) (15 9.33459) (16 8.11522) (17 9.44085) (18 9.67351) (19 8.46927) (20 9.73772) (21 9.46457) */
DEF_STATIC_CONST_VAL_CONS(g0614, (void*)&g0467, 0);
DEF_STATIC_CONST_VAL_CONS(g0613, (void*)&g0465, (void*)&g0614);
DEF_STATIC_CONST_VAL_CONS(g0612, (void*)&g0446, (void*)&g0613);
DEF_STATIC_CONST_VAL_CONS(g0611, (void*)&g0444, (void*)&g0612);
DEF_STATIC_CONST_VAL_CONS(g0610, (void*)&g0442, (void*)&g0611);
DEF_STATIC_CONST_VAL_CONS(g0609, (void*)&g0364, (void*)&g0610);
DEF_STATIC_CONST_VAL_CONS(g0608, (void*)&g0176, (void*)&g0609);
DEF_STATIC_CONST_VAL_CONS(g0607, (void*)&g0174, (void*)&g0608);
DEF_STATIC_CONST_VAL_CONS(g0606, (void*)&g0172, (void*)&g0607);
DEF_STATIC_CONST_VAL_CONS(g0605, (void*)&g0170, (void*)&g0606);
DEF_STATIC_CONST_VAL_CONS(g0604, (void*)&g0074, (void*)&g0605);
DEF_STATIC_CONST_VAL_CONS(g0603, (void*)&g0047, (void*)&g0604);
DEF_STATIC_CONST_VAL_CONS(g0602, (void*)&g0045, (void*)&g0603);
DEF_STATIC_CONST_VAL_CONS(g0601, (void*)&g0043, (void*)&g0602);
DEF_STATIC_CONST_VAL_CONS(g0600, (void*)&g0041, (void*)&g0601);
DEF_STATIC_CONST_VAL_CONS(g0599, (void*)&g0010, (void*)&g0600);
DEF_STATIC_CONST_VAL_CONS(g0598, (void*)&g0008, (void*)&g0599);
DEF_STATIC_CONST_VAL_CONS(g0597, (void*)&g0004, (void*)&g0598);
DEF_STATIC_CONST_VAL_CONS(g0596, (void*)&g0002, (void*)&g0597);
DEF_STATIC_CONST_VAL_CONS(cl_0121, (void*)&g0000, (void*)&g0596);

/* (aw_now) (0 7.32632) (1 6.89823) (2 6.24275) (3 6.46568) (4 6.25962) (5 6.84443) (7 7.7679) (8 6.27233) (9 7.61851) (10 6.36247) (11 5.11112) (12 6.20499) (13 6.44487) (14 5.89044) (15 5.7917) (16 6.29519) (17 6.23331) (19 6.16715) (20 6.15146) (21 7.63881) */
DEF_STATIC_CONST_VAL_CONS(g0633, (void*)&g0467, 0);
DEF_STATIC_CONST_VAL_CONS(g0632, (void*)&g0465, (void*)&g0633);
DEF_STATIC_CONST_VAL_CONS(g0631, (void*)&g0446, (void*)&g0632);
DEF_STATIC_CONST_VAL_CONS(g0630, (void*)&g0442, (void*)&g0631);
DEF_STATIC_CONST_VAL_CONS(g0629, (void*)&g0364, (void*)&g0630);
DEF_STATIC_CONST_VAL_CONS(g0628, (void*)&g0176, (void*)&g0629);
DEF_STATIC_CONST_VAL_CONS(g0627, (void*)&g0174, (void*)&g0628);
DEF_STATIC_CONST_VAL_CONS(g0626, (void*)&g0172, (void*)&g0627);
DEF_STATIC_CONST_VAL_CONS(g0625, (void*)&g0170, (void*)&g0626);
DEF_STATIC_CONST_VAL_CONS(g0624, (void*)&g0168, (void*)&g0625);
DEF_STATIC_CONST_VAL_CONS(g0623, (void*)&g0074, (void*)&g0624);
DEF_STATIC_CONST_VAL_CONS(g0622, (void*)&g0047, (void*)&g0623);
DEF_STATIC_CONST_VAL_CONS(g0621, (void*)&g0045, (void*)&g0622);
DEF_STATIC_CONST_VAL_CONS(g0620, (void*)&g0043, (void*)&g0621);
DEF_STATIC_CONST_VAL_CONS(g0619, (void*)&g0010, (void*)&g0620);
DEF_STATIC_CONST_VAL_CONS(g0618, (void*)&g0008, (void*)&g0619);
DEF_STATIC_CONST_VAL_CONS(g0617, (void*)&g0006, (void*)&g0618);
DEF_STATIC_CONST_VAL_CONS(g0616, (void*)&g0004, (void*)&g0617);
DEF_STATIC_CONST_VAL_CONS(g0615, (void*)&g0002, (void*)&g0616);
DEF_STATIC_CONST_VAL_CONS(cl_0122, (void*)&g0000, (void*)&g0615);

/* (n_now) (0 7.8949) (3 6.7977) (4 7.08406) (5 7.71552) (7 7.83721) (8 8.63599) (9 6.88012) (10 8.36962) (11 7.45531) (12 7.89038) (13 6.72187) (14 8.13619) (15 6.8314) (16 8.11249) (17 7.91684) (18 7.52108) (19 8.40547) (20 6.79064) (21 6.80533) (23 7.365) */
DEF_STATIC_CONST_VAL_FLOAT(g0653,23);
DEF_STATIC_CONST_VAL_CONS(g0652, (void*)&g0653, 0);
DEF_STATIC_CONST_VAL_CONS(g0651, (void*)&g0467, (void*)&g0652);
DEF_STATIC_CONST_VAL_CONS(g0650, (void*)&g0465, (void*)&g0651);
DEF_STATIC_CONST_VAL_CONS(g0649, (void*)&g0446, (void*)&g0650);
DEF_STATIC_CONST_VAL_CONS(g0648, (void*)&g0444, (void*)&g0649);
DEF_STATIC_CONST_VAL_CONS(g0647, (void*)&g0442, (void*)&g0648);
DEF_STATIC_CONST_VAL_CONS(g0646, (void*)&g0364, (void*)&g0647);
DEF_STATIC_CONST_VAL_CONS(g0645, (void*)&g0176, (void*)&g0646);
DEF_STATIC_CONST_VAL_CONS(g0644, (void*)&g0174, (void*)&g0645);
DEF_STATIC_CONST_VAL_CONS(g0643, (void*)&g0172, (void*)&g0644);
DEF_STATIC_CONST_VAL_CONS(g0642, (void*)&g0170, (void*)&g0643);
DEF_STATIC_CONST_VAL_CONS(g0641, (void*)&g0168, (void*)&g0642);
DEF_STATIC_CONST_VAL_CONS(g0640, (void*)&g0074, (void*)&g0641);
DEF_STATIC_CONST_VAL_CONS(g0639, (void*)&g0047, (void*)&g0640);
DEF_STATIC_CONST_VAL_CONS(g0638, (void*)&g0045, (void*)&g0639);
DEF_STATIC_CONST_VAL_CONS(g0637, (void*)&g0043, (void*)&g0638);
DEF_STATIC_CONST_VAL_CONS(g0636, (void*)&g0010, (void*)&g0637);
DEF_STATIC_CONST_VAL_CONS(g0635, (void*)&g0008, (void*)&g0636);
DEF_STATIC_CONST_VAL_CONS(g0634, (void*)&g0006, (void*)&g0635);
DEF_STATIC_CONST_VAL_CONS(cl_0123, (void*)&g0000, (void*)&g0634);

/* (z_is) (0 8.41652) (1 6.46199) (2 7.43602) (3 6.19504) (4 7.80479) (5 8.31326) (6 6.02612) (7 6.76408) (9 8.05606) (10 7.56576) (11 6.43609) (12 7.2576) (13 6.57458) (14 9.27794) (15 6.73229) (16 7.60847) (18 7.15274) (19 7.61916) (20 7.97835) (21 6.9203) */
DEF_STATIC_CONST_VAL_CONS(g0672, (void*)&g0467, 0);
DEF_STATIC_CONST_VAL_CONS(g0671, (void*)&g0465, (void*)&g0672);
DEF_STATIC_CONST_VAL_CONS(g0670, (void*)&g0446, (void*)&g0671);
DEF_STATIC_CONST_VAL_CONS(g0669, (void*)&g0444, (void*)&g0670);
DEF_STATIC_CONST_VAL_CONS(g0668, (void*)&g0364, (void*)&g0669);
DEF_STATIC_CONST_VAL_CONS(g0667, (void*)&g0176, (void*)&g0668);
DEF_STATIC_CONST_VAL_CONS(g0666, (void*)&g0174, (void*)&g0667);
DEF_STATIC_CONST_VAL_CONS(g0665, (void*)&g0172, (void*)&g0666);
DEF_STATIC_CONST_VAL_CONS(g0664, (void*)&g0170, (void*)&g0665);
DEF_STATIC_CONST_VAL_CONS(g0663, (void*)&g0168, (void*)&g0664);
DEF_STATIC_CONST_VAL_CONS(g0662, (void*)&g0074, (void*)&g0663);
DEF_STATIC_CONST_VAL_CONS(g0661, (void*)&g0047, (void*)&g0662);
DEF_STATIC_CONST_VAL_CONS(g0660, (void*)&g0043, (void*)&g0661);
DEF_STATIC_CONST_VAL_CONS(g0659, (void*)&g0041, (void*)&g0660);
DEF_STATIC_CONST_VAL_CONS(g0658, (void*)&g0010, (void*)&g0659);
DEF_STATIC_CONST_VAL_CONS(g0657, (void*)&g0008, (void*)&g0658);
DEF_STATIC_CONST_VAL_CONS(g0656, (void*)&g0006, (void*)&g0657);
DEF_STATIC_CONST_VAL_CONS(g0655, (void*)&g0004, (void*)&g0656);
DEF_STATIC_CONST_VAL_CONS(g0654, (void*)&g0002, (void*)&g0655);
DEF_STATIC_CONST_VAL_CONS(cl_0124, (void*)&g0000, (void*)&g0654);

/* (ih_is) (0 6.51315) (1 5.72634) (2 6.5887) (4 6.1734) (5 7.65526) (6 8.83502) (7 5.73597) (9 5.88695) (10 8.11027) (11 5.35931) (12 6.27415) (13 7.49397) (15 7.36096) (16 8.55616) (17 5.84935) (18 5.34531) (19 6.44897) (20 7.08473) (21 7.44499) (22 7.41112) */
DEF_STATIC_CONST_VAL_FLOAT(g0692,22);
DEF_STATIC_CONST_VAL_CONS(g0691, (void*)&g0692, 0);
DEF_STATIC_CONST_VAL_CONS(g0690, (void*)&g0467, (void*)&g0691);
DEF_STATIC_CONST_VAL_CONS(g0689, (void*)&g0465, (void*)&g0690);
DEF_STATIC_CONST_VAL_CONS(g0688, (void*)&g0446, (void*)&g0689);
DEF_STATIC_CONST_VAL_CONS(g0687, (void*)&g0444, (void*)&g0688);
DEF_STATIC_CONST_VAL_CONS(g0686, (void*)&g0442, (void*)&g0687);
DEF_STATIC_CONST_VAL_CONS(g0685, (void*)&g0364, (void*)&g0686);
DEF_STATIC_CONST_VAL_CONS(g0684, (void*)&g0176, (void*)&g0685);
DEF_STATIC_CONST_VAL_CONS(g0683, (void*)&g0172, (void*)&g0684);
DEF_STATIC_CONST_VAL_CONS(g0682, (void*)&g0170, (void*)&g0683);
DEF_STATIC_CONST_VAL_CONS(g0681, (void*)&g0168, (void*)&g0682);
DEF_STATIC_CONST_VAL_CONS(g0680, (void*)&g0074, (void*)&g0681);
DEF_STATIC_CONST_VAL_CONS(g0679, (void*)&g0047, (void*)&g0680);
DEF_STATIC_CONST_VAL_CONS(g0678, (void*)&g0043, (void*)&g0679);
DEF_STATIC_CONST_VAL_CONS(g0677, (void*)&g0041, (void*)&g0678);
DEF_STATIC_CONST_VAL_CONS(g0676, (void*)&g0010, (void*)&g0677);
DEF_STATIC_CONST_VAL_CONS(g0675, (void*)&g0008, (void*)&g0676);
DEF_STATIC_CONST_VAL_CONS(g0674, (void*)&g0004, (void*)&g0675);
DEF_STATIC_CONST_VAL_CONS(g0673, (void*)&g0002, (void*)&g0674);
DEF_STATIC_CONST_VAL_CONS(cl_0125, (void*)&g0000, (void*)&g0673);

/* (m_time) (0 5.82376) (1 6.54247) (2 5.77884) (3 5.9918) (4 7.41018) (5 8.76128) (6 6.81936) (7 6.51969) (9 5.46876) (10 6.99871) (11 8.08768) (12 7.41414) (13 6.20682) (14 8.89504) (15 6.05312) (16 6.42317) (17 8.17411) (18 6.11061) (19 5.86005) (20 6.59706) */
DEF_STATIC_CONST_VAL_CONS(g0711, (void*)&g0465, 0);
DEF_STATIC_CONST_VAL_CONS(g0710, (void*)&g0446, (void*)&g0711);
DEF_STATIC_CONST_VAL_CONS(g0709, (void*)&g0444, (void*)&g0710);
DEF_STATIC_CONST_VAL_CONS(g0708, (void*)&g0442, (void*)&g0709);
DEF_STATIC_CONST_VAL_CONS(g0707, (void*)&g0364, (void*)&g0708);
DEF_STATIC_CONST_VAL_CONS(g0706, (void*)&g0176, (void*)&g0707);
DEF_STATIC_CONST_VAL_CONS(g0705, (void*)&g0174, (void*)&g0706);
DEF_STATIC_CONST_VAL_CONS(g0704, (void*)&g0172, (void*)&g0705);
DEF_STATIC_CONST_VAL_CONS(g0703, (void*)&g0170, (void*)&g0704);
DEF_STATIC_CONST_VAL_CONS(g0702, (void*)&g0168, (void*)&g0703);
DEF_STATIC_CONST_VAL_CONS(g0701, (void*)&g0074, (void*)&g0702);
DEF_STATIC_CONST_VAL_CONS(g0700, (void*)&g0047, (void*)&g0701);
DEF_STATIC_CONST_VAL_CONS(g0699, (void*)&g0043, (void*)&g0700);
DEF_STATIC_CONST_VAL_CONS(g0698, (void*)&g0041, (void*)&g0699);
DEF_STATIC_CONST_VAL_CONS(g0697, (void*)&g0010, (void*)&g0698);
DEF_STATIC_CONST_VAL_CONS(g0696, (void*)&g0008, (void*)&g0697);
DEF_STATIC_CONST_VAL_CONS(g0695, (void*)&g0006, (void*)&g0696);
DEF_STATIC_CONST_VAL_CONS(g0694, (void*)&g0004, (void*)&g0695);
DEF_STATIC_CONST_VAL_CONS(g0693, (void*)&g0002, (void*)&g0694);
DEF_STATIC_CONST_VAL_CONS(cl_0126, (void*)&g0000, (void*)&g0693);

/* (ay_time) (0 8.1165) (1 8.12996) (2 6.05075) (3 8.20537) (4 8.23893) (5 8.23073) (6 7.9109) (7 7.81784) (8 6.57692) (9 6.28514) (10 7.0142) (11 5.90095) (12 6.90132) (13 6.15903) (15 6.51599) (17 7.95861) (18 6.9983) (20 6.97445) (21 6.32031) (22 7.53298) */
DEF_STATIC_CONST_VAL_CONS(g0730, (void*)&g0692, 0);
DEF_STATIC_CONST_VAL_CONS(g0729, (void*)&g0467, (void*)&g0730);
DEF_STATIC_CONST_VAL_CONS(g0728, (void*)&g0465, (void*)&g0729);
DEF_STATIC_CONST_VAL_CONS(g0727, (void*)&g0444, (void*)&g0728);
DEF_STATIC_CONST_VAL_CONS(g0726, (void*)&g0442, (void*)&g0727);
DEF_STATIC_CONST_VAL_CONS(g0725, (void*)&g0176, (void*)&g0726);
DEF_STATIC_CONST_VAL_CONS(g0724, (void*)&g0172, (void*)&g0725);
DEF_STATIC_CONST_VAL_CONS(g0723, (void*)&g0170, (void*)&g0724);
DEF_STATIC_CONST_VAL_CONS(g0722, (void*)&g0168, (void*)&g0723);
DEF_STATIC_CONST_VAL_CONS(g0721, (void*)&g0074, (void*)&g0722);
DEF_STATIC_CONST_VAL_CONS(g0720, (void*)&g0047, (void*)&g0721);
DEF_STATIC_CONST_VAL_CONS(g0719, (void*)&g0045, (void*)&g0720);
DEF_STATIC_CONST_VAL_CONS(g0718, (void*)&g0043, (void*)&g0719);
DEF_STATIC_CONST_VAL_CONS(g0717, (void*)&g0041, (void*)&g0718);
DEF_STATIC_CONST_VAL_CONS(g0716, (void*)&g0010, (void*)&g0717);
DEF_STATIC_CONST_VAL_CONS(g0715, (void*)&g0008, (void*)&g0716);
DEF_STATIC_CONST_VAL_CONS(g0714, (void*)&g0006, (void*)&g0715);
DEF_STATIC_CONST_VAL_CONS(g0713, (void*)&g0004, (void*)&g0714);
DEF_STATIC_CONST_VAL_CONS(g0712, (void*)&g0002, (void*)&g0713);
DEF_STATIC_CONST_VAL_CONS(cl_0127, (void*)&g0000, (void*)&g0712);

/* (t_time) (0 10.6282) (1 10.2797) (2 9.59597) (3 10.2137) (4 8.66417) (5 10.1115) (6 10.8021) (8 10.2918) (9 9.34911) (11 9.65092) (12 8.63932) (14 10.9298) (16 9.0089) (17 9.32812) (18 10.641) (19 10.5819) (20 9.67297) (21 9.64739) (22 9.06107) (23 8.57466) */
DEF_STATIC_CONST_VAL_CONS(g0749, (void*)&g0653, 0);
DEF_STATIC_CONST_VAL_CONS(g0748, (void*)&g0692, (void*)&g0749);
DEF_STATIC_CONST_VAL_CONS(g0747, (void*)&g0467, (void*)&g0748);
DEF_STATIC_CONST_VAL_CONS(g0746, (void*)&g0465, (void*)&g0747);
DEF_STATIC_CONST_VAL_CONS(g0745, (void*)&g0446, (void*)&g0746);
DEF_STATIC_CONST_VAL_CONS(g0744, (void*)&g0444, (void*)&g0745);
DEF_STATIC_CONST_VAL_CONS(g0743, (void*)&g0442, (void*)&g0744);
DEF_STATIC_CONST_VAL_CONS(g0742, (void*)&g0364, (void*)&g0743);
DEF_STATIC_CONST_VAL_CONS(g0741, (void*)&g0174, (void*)&g0742);
DEF_STATIC_CONST_VAL_CONS(g0740, (void*)&g0170, (void*)&g0741);
DEF_STATIC_CONST_VAL_CONS(g0739, (void*)&g0168, (void*)&g0740);
DEF_STATIC_CONST_VAL_CONS(g0738, (void*)&g0047, (void*)&g0739);
DEF_STATIC_CONST_VAL_CONS(g0737, (void*)&g0045, (void*)&g0738);
DEF_STATIC_CONST_VAL_CONS(g0736, (void*)&g0041, (void*)&g0737);
DEF_STATIC_CONST_VAL_CONS(g0735, (void*)&g0010, (void*)&g0736);
DEF_STATIC_CONST_VAL_CONS(g0734, (void*)&g0008, (void*)&g0735);
DEF_STATIC_CONST_VAL_CONS(g0733, (void*)&g0006, (void*)&g0734);
DEF_STATIC_CONST_VAL_CONS(g0732, (void*)&g0004, (void*)&g0733);
DEF_STATIC_CONST_VAL_CONS(g0731, (void*)&g0002, (void*)&g0732);
DEF_STATIC_CONST_VAL_CONS(cl_0128, (void*)&g0000, (void*)&g0731);

/* (ax_the) (0 7.84321) (1 7.94119) (2 7.74991) (3 8.39139) (4 8.18299) (5 7.31176) (6 8.08511) (7 9.28368) (9 8.13302) (10 7.96881) (11 7.54287) (14 7.94034) (16 7.0467) (18 9.82816) (20 8.65536) (22 8.86905) (26 8.86181) (28 8.48341) (30 8.94159) (32 8.16568) */
DEF_STATIC_CONST_VAL_FLOAT(g0766,26);
DEF_STATIC_CONST_VAL_FLOAT(g0768,28);
DEF_STATIC_CONST_VAL_FLOAT(g0770,30);
DEF_STATIC_CONST_VAL_FLOAT(g0772,32);
DEF_STATIC_CONST_VAL_CONS(g0771, (void*)&g0772, 0);
DEF_STATIC_CONST_VAL_CONS(g0769, (void*)&g0770, (void*)&g0771);
DEF_STATIC_CONST_VAL_CONS(g0767, (void*)&g0768, (void*)&g0769);
DEF_STATIC_CONST_VAL_CONS(g0765, (void*)&g0766, (void*)&g0767);
DEF_STATIC_CONST_VAL_CONS(g0764, (void*)&g0692, (void*)&g0765);
DEF_STATIC_CONST_VAL_CONS(g0763, (void*)&g0465, (void*)&g0764);
DEF_STATIC_CONST_VAL_CONS(g0762, (void*)&g0444, (void*)&g0763);
DEF_STATIC_CONST_VAL_CONS(g0761, (void*)&g0364, (void*)&g0762);
DEF_STATIC_CONST_VAL_CONS(g0760, (void*)&g0174, (void*)&g0761);
DEF_STATIC_CONST_VAL_CONS(g0759, (void*)&g0168, (void*)&g0760);
DEF_STATIC_CONST_VAL_CONS(g0758, (void*)&g0074, (void*)&g0759);
DEF_STATIC_CONST_VAL_CONS(g0757, (void*)&g0047, (void*)&g0758);
DEF_STATIC_CONST_VAL_CONS(g0756, (void*)&g0043, (void*)&g0757);
DEF_STATIC_CONST_VAL_CONS(g0755, (void*)&g0041, (void*)&g0756);
DEF_STATIC_CONST_VAL_CONS(g0754, (void*)&g0010, (void*)&g0755);
DEF_STATIC_CONST_VAL_CONS(g0753, (void*)&g0008, (void*)&g0754);
DEF_STATIC_CONST_VAL_CONS(g0752, (void*)&g0006, (void*)&g0753);
DEF_STATIC_CONST_VAL_CONS(g0751, (void*)&g0004, (void*)&g0752);
DEF_STATIC_CONST_VAL_CONS(g0750, (void*)&g0002, (void*)&g0751);
DEF_STATIC_CONST_VAL_CONS(cl_0129, (void*)&g0000, (void*)&g0750);

/* (ax_the) (12 9.77745) (13 7.6618) (15 7.52716) (17 7.16051) (19 7.11524) (21 10.6398) (23 10.1488) (25 8.36649) (27 6.74594) (29 8.20911) (31 7.70626) */
DEF_STATIC_CONST_VAL_FLOAT(g0780,25);
DEF_STATIC_CONST_VAL_FLOAT(g0782,27);
DEF_STATIC_CONST_VAL_FLOAT(g0784,29);
DEF_STATIC_CONST_VAL_FLOAT(g0786,31);
DEF_STATIC_CONST_VAL_CONS(g0785, (void*)&g0786, 0);
DEF_STATIC_CONST_VAL_CONS(g0783, (void*)&g0784, (void*)&g0785);
DEF_STATIC_CONST_VAL_CONS(g0781, (void*)&g0782, (void*)&g0783);
DEF_STATIC_CONST_VAL_CONS(g0779, (void*)&g0780, (void*)&g0781);
DEF_STATIC_CONST_VAL_CONS(g0778, (void*)&g0653, (void*)&g0779);
DEF_STATIC_CONST_VAL_CONS(g0777, (void*)&g0467, (void*)&g0778);
DEF_STATIC_CONST_VAL_CONS(g0776, (void*)&g0446, (void*)&g0777);
DEF_STATIC_CONST_VAL_CONS(g0775, (void*)&g0442, (void*)&g0776);
DEF_STATIC_CONST_VAL_CONS(g0774, (void*)&g0176, (void*)&g0775);
DEF_STATIC_CONST_VAL_CONS(g0773, (void*)&g0172, (void*)&g0774);
DEF_STATIC_CONST_VAL_CONS(cl_0130, (void*)&g0170, (void*)&g0773);

/* (dh_the) (1 8.25582) (5 9.66382) (7 8.92079) (9 9.46275) (13 10.4693) (15 9.81428) (17 8.95891) (19 7.99034) (21 7.71793) (24 7.74793) (25 7.34069) (27 8.36013) (29 7.71913) (31 7.0906) (33 8.79822) (35 8.08141) (37 8.41373) (39 9.38801) (41 7.59643) (43 9.20379) */
DEF_STATIC_CONST_VAL_FLOAT(g0796,24);
DEF_STATIC_CONST_VAL_FLOAT(g0802,33);
DEF_STATIC_CONST_VAL_FLOAT(g0804,35);
DEF_STATIC_CONST_VAL_FLOAT(g0806,37);
DEF_STATIC_CONST_VAL_FLOAT(g0808,39);
DEF_STATIC_CONST_VAL_FLOAT(g0810,41);
DEF_STATIC_CONST_VAL_FLOAT(g0812,43);
DEF_STATIC_CONST_VAL_CONS(g0811, (void*)&g0812, 0);
DEF_STATIC_CONST_VAL_CONS(g0809, (void*)&g0810, (void*)&g0811);
DEF_STATIC_CONST_VAL_CONS(g0807, (void*)&g0808, (void*)&g0809);
DEF_STATIC_CONST_VAL_CONS(g0805, (void*)&g0806, (void*)&g0807);
DEF_STATIC_CONST_VAL_CONS(g0803, (void*)&g0804, (void*)&g0805);
DEF_STATIC_CONST_VAL_CONS(g0801, (void*)&g0802, (void*)&g0803);
DEF_STATIC_CONST_VAL_CONS(g0800, (void*)&g0786, (void*)&g0801);
DEF_STATIC_CONST_VAL_CONS(g0799, (void*)&g0784, (void*)&g0800);
DEF_STATIC_CONST_VAL_CONS(g0798, (void*)&g0782, (void*)&g0799);
DEF_STATIC_CONST_VAL_CONS(g0797, (void*)&g0780, (void*)&g0798);
DEF_STATIC_CONST_VAL_CONS(g0795, (void*)&g0796, (void*)&g0797);
DEF_STATIC_CONST_VAL_CONS(g0794, (void*)&g0467, (void*)&g0795);
DEF_STATIC_CONST_VAL_CONS(g0793, (void*)&g0446, (void*)&g0794);
DEF_STATIC_CONST_VAL_CONS(g0792, (void*)&g0442, (void*)&g0793);
DEF_STATIC_CONST_VAL_CONS(g0791, (void*)&g0176, (void*)&g0792);
DEF_STATIC_CONST_VAL_CONS(g0790, (void*)&g0172, (void*)&g0791);
DEF_STATIC_CONST_VAL_CONS(g0789, (void*)&g0047, (void*)&g0790);
DEF_STATIC_CONST_VAL_CONS(g0788, (void*)&g0043, (void*)&g0789);
DEF_STATIC_CONST_VAL_CONS(g0787, (void*)&g0010, (void*)&g0788);
DEF_STATIC_CONST_VAL_CONS(cl_0131, (void*)&g0002, (void*)&g0787);

/* (dh_the) (0 6.35245) (2 7.48187) (4 7.18551) (8 7.2523) (10 7.08969) (12 7.62295) (14 8.1208) (16 7.42866) (18 7.18355) (20 7.36611) (22 7.53647) (23 6.88105) (26 7.50443) (28 7.00309) (30 7.92787) (36 7.43062) (38 7.41111) (40 6.45587) (42 7.87527) (44 6.88369) */
DEF_STATIC_CONST_VAL_FLOAT(g0828,36);
DEF_STATIC_CONST_VAL_FLOAT(g0830,38);
DEF_STATIC_CONST_VAL_FLOAT(g0832,40);
DEF_STATIC_CONST_VAL_FLOAT(g0834,42);
DEF_STATIC_CONST_VAL_FLOAT(g0836,44);
DEF_STATIC_CONST_VAL_CONS(g0835, (void*)&g0836, 0);
DEF_STATIC_CONST_VAL_CONS(g0833, (void*)&g0834, (void*)&g0835);
DEF_STATIC_CONST_VAL_CONS(g0831, (void*)&g0832, (void*)&g0833);
DEF_STATIC_CONST_VAL_CONS(g0829, (void*)&g0830, (void*)&g0831);
DEF_STATIC_CONST_VAL_CONS(g0827, (void*)&g0828, (void*)&g0829);
DEF_STATIC_CONST_VAL_CONS(g0826, (void*)&g0770, (void*)&g0827);
DEF_STATIC_CONST_VAL_CONS(g0825, (void*)&g0768, (void*)&g0826);
DEF_STATIC_CONST_VAL_CONS(g0824, (void*)&g0766, (void*)&g0825);
DEF_STATIC_CONST_VAL_CONS(g0823, (void*)&g0653, (void*)&g0824);
DEF_STATIC_CONST_VAL_CONS(g0822, (void*)&g0692, (void*)&g0823);
DEF_STATIC_CONST_VAL_CONS(g0821, (void*)&g0465, (void*)&g0822);
DEF_STATIC_CONST_VAL_CONS(g0820, (void*)&g0444, (void*)&g0821);
DEF_STATIC_CONST_VAL_CONS(g0819, (void*)&g0364, (void*)&g0820);
DEF_STATIC_CONST_VAL_CONS(g0818, (void*)&g0174, (void*)&g0819);
DEF_STATIC_CONST_VAL_CONS(g0817, (void*)&g0170, (void*)&g0818);
DEF_STATIC_CONST_VAL_CONS(g0816, (void*)&g0074, (void*)&g0817);
DEF_STATIC_CONST_VAL_CONS(g0815, (void*)&g0045, (void*)&g0816);
DEF_STATIC_CONST_VAL_CONS(g0814, (void*)&g0008, (void*)&g0815);
DEF_STATIC_CONST_VAL_CONS(g0813, (void*)&g0004, (void*)&g0814);
DEF_STATIC_CONST_VAL_CONS(cl_0132, (void*)&g0000, (void*)&g0813);

/* (pau_pau) (0 10.9167) (1 11.9909) (2 10.9192) (5 11.5265) (6 12.1171) (8 11.986) (9 10.3795) (10 11.313) (11 10.8246) (12 11.2407) (13 10.9218) (14 10.8178) (15 11.5849) (17 12.4593) (18 11.7944) (19 11.6695) (20 12.1442) (21 10.994) (22 12.4074) (23 11.8404) */
DEF_STATIC_CONST_VAL_CONS(g0855, (void*)&g0653, 0);
DEF_STATIC_CONST_VAL_CONS(g0854, (void*)&g0692, (void*)&g0855);
DEF_STATIC_CONST_VAL_CONS(g0853, (void*)&g0467, (void*)&g0854);
DEF_STATIC_CONST_VAL_CONS(g0852, (void*)&g0465, (void*)&g0853);
DEF_STATIC_CONST_VAL_CONS(g0851, (void*)&g0446, (void*)&g0852);
DEF_STATIC_CONST_VAL_CONS(g0850, (void*)&g0444, (void*)&g0851);
DEF_STATIC_CONST_VAL_CONS(g0849, (void*)&g0442, (void*)&g0850);
DEF_STATIC_CONST_VAL_CONS(g0848, (void*)&g0176, (void*)&g0849);
DEF_STATIC_CONST_VAL_CONS(g0847, (void*)&g0174, (void*)&g0848);
DEF_STATIC_CONST_VAL_CONS(g0846, (void*)&g0172, (void*)&g0847);
DEF_STATIC_CONST_VAL_CONS(g0845, (void*)&g0170, (void*)&g0846);
DEF_STATIC_CONST_VAL_CONS(g0844, (void*)&g0168, (void*)&g0845);
DEF_STATIC_CONST_VAL_CONS(g0843, (void*)&g0074, (void*)&g0844);
DEF_STATIC_CONST_VAL_CONS(g0842, (void*)&g0047, (void*)&g0843);
DEF_STATIC_CONST_VAL_CONS(g0841, (void*)&g0045, (void*)&g0842);
DEF_STATIC_CONST_VAL_CONS(g0840, (void*)&g0041, (void*)&g0841);
DEF_STATIC_CONST_VAL_CONS(g0839, (void*)&g0010, (void*)&g0840);
DEF_STATIC_CONST_VAL_CONS(g0838, (void*)&g0004, (void*)&g0839);
DEF_STATIC_CONST_VAL_CONS(g0837, (void*)&g0002, (void*)&g0838);
DEF_STATIC_CONST_VAL_CONS(cl_0133, (void*)&g0000, (void*)&g0837);

/* (pau_0) (0 12.0936) (1 11.4571) (2 12.9788) (3 10.8239) (4 11.4452) (5 10.6585) (6 9.83629) (7 13.0182) (8 11.1205) (9 12.01) (10 11.1297) (11 12.6706) (12 13.7608) (13 11.5566) (14 13.668) (15 10.663) (16 11.3106) (17 11.8575) (18 10.9482) (19 10.3591) */
DEF_STATIC_CONST_VAL_CONS(g0874, (void*)&g0446, 0);
DEF_STATIC_CONST_VAL_CONS(g0873, (void*)&g0444, (void*)&g0874);
DEF_STATIC_CONST_VAL_CONS(g0872, (void*)&g0442, (void*)&g0873);
DEF_STATIC_CONST_VAL_CONS(g0871, (void*)&g0364, (void*)&g0872);
DEF_STATIC_CONST_VAL_CONS(g0870, (void*)&g0176, (void*)&g0871);
DEF_STATIC_CONST_VAL_CONS(g0869, (void*)&g0174, (void*)&g0870);
DEF_STATIC_CONST_VAL_CONS(g0868, (void*)&g0172, (void*)&g0869);
DEF_STATIC_CONST_VAL_CONS(g0867, (void*)&g0170, (void*)&g0868);
DEF_STATIC_CONST_VAL_CONS(g0866, (void*)&g0168, (void*)&g0867);
DEF_STATIC_CONST_VAL_CONS(g0865, (void*)&g0074, (void*)&g0866);
DEF_STATIC_CONST_VAL_CONS(g0864, (void*)&g0047, (void*)&g0865);
DEF_STATIC_CONST_VAL_CONS(g0863, (void*)&g0045, (void*)&g0864);
DEF_STATIC_CONST_VAL_CONS(g0862, (void*)&g0043, (void*)&g0863);
DEF_STATIC_CONST_VAL_CONS(g0861, (void*)&g0041, (void*)&g0862);
DEF_STATIC_CONST_VAL_CONS(g0860, (void*)&g0010, (void*)&g0861);
DEF_STATIC_CONST_VAL_CONS(g0859, (void*)&g0008, (void*)&g0860);
DEF_STATIC_CONST_VAL_CONS(g0858, (void*)&g0006, (void*)&g0859);
DEF_STATIC_CONST_VAL_CONS(g0857, (void*)&g0004, (void*)&g0858);
DEF_STATIC_CONST_VAL_CONS(g0856, (void*)&g0002, (void*)&g0857);
DEF_STATIC_CONST_VAL_CONS(cl_0134, (void*)&g0000, (void*)&g0856);


/* Shared feature table */
static const char * const cmu_time_awb_feature_table[] = {
	"R:SylStructure.parent.R:Syllable.p.syl_break",
	"p.name",
	NULL
};

/* CART tree for unit type t_midnight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_midnight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0000 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_midnight_cart = {
	t_midnight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ay_midnight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ay_midnight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0001 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ay_midnight_cart = {
	ay_midnight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_midnight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_midnight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0002 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_midnight_cart = {
	n_midnight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type d_midnight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node d_midnight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0003 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart d_midnight_cart = {
	d_midnight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_midnight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_midnight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0004 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_midnight_cart = {
	ih_midnight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type m_midnight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node m_midnight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0005 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart m_midnight_cart = {
	m_midnight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ng_evening */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ng_evening_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0006 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ng_evening_cart = {
	ng_evening_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_evening */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_evening_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0007 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_evening_cart = {
	ih_evening_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_evening */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_evening_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0008 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_evening_cart = {
	n_evening_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type v_evening */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node v_evening_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0009 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart v_evening_cart = {
	v_evening_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type iy_evening */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node iy_evening_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0010 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart iy_evening_cart = {
	iy_evening_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type uw_afternoon */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node uw_afternoon_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0011 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart uw_afternoon_cart = {
	uw_afternoon_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_afternoon */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_afternoon_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0012 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_afternoon_cart = {
	n_afternoon_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type er_afternoon */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node er_afternoon_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0013 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart er_afternoon_cart = {
	er_afternoon_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_afternoon */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_afternoon_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0014 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_afternoon_cart = {
	t_afternoon_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type f_afternoon */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node f_afternoon_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0015 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart f_afternoon_cart = {
	f_afternoon_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ae_afternoon */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ae_afternoon_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0016 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ae_afternoon_cart = {
	ae_afternoon_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type iy_the */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node iy_the_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0017 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart iy_the_cart = {
	iy_the_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type v_twelve */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node v_twelve_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0018 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart v_twelve_cart = {
	v_twelve_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type l_twelve */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node l_twelve_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0019 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart l_twelve_cart = {
	l_twelve_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type eh_twelve */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node eh_twelve_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0020 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart eh_twelve_cart = {
	eh_twelve_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type w_twelve */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node w_twelve_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0021 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart w_twelve_cart = {
	w_twelve_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_twelve */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_twelve_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0022 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_twelve_cart = {
	t_twelve_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_eleven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_eleven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0023 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_eleven_cart = {
	n_eleven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ax_eleven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ax_eleven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0024 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ax_eleven_cart = {
	ax_eleven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type v_eleven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node v_eleven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0025 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart v_eleven_cart = {
	v_eleven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type eh_eleven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node eh_eleven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0026 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart eh_eleven_cart = {
	eh_eleven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type l_eleven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node l_eleven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0027 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart l_eleven_cart = {
	l_eleven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_eleven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_eleven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0028 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_eleven_cart = {
	ih_eleven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ay_nine */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ay_nine_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0029 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ay_nine_cart = {
	ay_nine_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_nine */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_nine_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0030 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_nine_cart = {
	n_nine_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_t */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_t_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0031 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_t_cart = {
	pau_t_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_eight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_eight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0032 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_eight_cart = {
	t_eight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ey_eight */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ey_eight_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0033 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ey_eight_cart = {
	ey_eight_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_seven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_seven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0034 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_seven_cart = {
	n_seven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ax_seven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ax_seven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0035 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ax_seven_cart = {
	ax_seven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type v_seven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node v_seven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0036 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart v_seven_cart = {
	v_seven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type eh_seven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node eh_seven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0037 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart eh_seven_cart = {
	eh_seven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type s_seven */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node s_seven_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0038 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart s_seven_cart = {
	s_seven_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ax_to */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ax_to_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0039 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ax_to_cart = {
	ax_to_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_to */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_to_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0040 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_to_cart = {
	t_to_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_s */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_s_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0041 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_s_cart = {
	pau_s_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type k_six */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node k_six_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0042 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart k_six_cart = {
	k_six_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_six */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_six_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0043 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_six_cart = {
	ih_six_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type s_six */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node s_six_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0044 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart s_six_cart = {
	s_six_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type f_half */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node f_half_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0045 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart f_half_cart = {
	f_half_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ae_half */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ae_half_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0046 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ae_half_cart = {
	ae_half_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type hh_half */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node hh_half_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0047 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart hh_half_cart = {
	hh_half_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_v */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_v_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0048 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_v_cart = {
	pau_v_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_r */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_r_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0049 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_r_cart = {
	pau_r_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type r_four */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node r_four_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0050 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart r_four_cart = {
	r_four_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ao_four */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ao_four_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0051 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ao_four_cart = {
	ao_four_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type f_four */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node f_four_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0052 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart f_four_cart = {
	f_four_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type iy_twenty */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node iy_twenty_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0053 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart iy_twenty_cart = {
	iy_twenty_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_twenty */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_twenty_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0054 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_twenty_cart = {
	n_twenty_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type eh_twenty */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node eh_twenty_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0055 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart eh_twenty_cart = {
	eh_twenty_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type w_twenty */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node w_twenty_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0056 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart w_twenty_cart = {
	w_twenty_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_twenty */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_twenty_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0057 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_twenty_cart = {
	t_twenty_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_almost */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_almost_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0058 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_almost_cart = {
	t_almost_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type s_almost */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node s_almost_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0059 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart s_almost_cart = {
	s_almost_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ow_almost */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ow_almost_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0060 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ow_almost_cart = {
	ow_almost_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type m_almost */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node m_almost_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0061 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart m_almost_cart = {
	m_almost_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type l_almost */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node l_almost_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0062 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart l_almost_cart = {
	l_almost_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ao_almost */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ao_almost_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0063 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ao_almost_cart = {
	ao_almost_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_iy */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_iy_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0064 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_iy_cart = {
	pau_iy_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type iy_three */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node iy_three_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0065 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart iy_three_cart = {
	iy_three_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type r_three */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node r_three_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0066 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart r_three_cart = {
	r_three_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type th_three */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node th_three_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0067 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart th_three_cart = {
	th_three_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type er_quarter */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node er_quarter_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0068 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart er_quarter_cart = {
	er_quarter_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_quarter */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_quarter_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0069 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_quarter_cart = {
	t_quarter_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type r_quarter */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node r_quarter_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0070 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart r_quarter_cart = {
	r_quarter_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ao_quarter */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ao_quarter_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0071 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ao_quarter_cart = {
	ao_quarter_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type w_quarter */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node w_quarter_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0072 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart w_quarter_cart = {
	w_quarter_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type k_quarter */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node k_quarter_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0073 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart k_quarter_cart = {
	k_quarter_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ax_little */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ax_little_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0074 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ax_little_cart = {
	ax_little_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_little */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_little_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0075 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_little_cart = {
	t_little_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_little */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_little_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0076 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_little_cart = {
	ih_little_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type l_little */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node l_little_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0077 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart l_little_cart = {
	l_little_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ax_a */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ax_a_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0078 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ax_a_cart = {
	ax_a_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_uw */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_uw_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0079 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_uw_cart = {
	pau_uw_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type uw_two */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node uw_two_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0080 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart uw_two_cart = {
	uw_two_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_two */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_two_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0081 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_two_cart = {
	t_two_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_ten */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_ten_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0082 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_ten_cart = {
	n_ten_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type eh_ten */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node eh_ten_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0083 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart eh_ten_cart = {
	eh_ten_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_ten */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_ten_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0084 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_ten_cart = {
	t_ten_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type er_after */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node er_after_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0085 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart er_after_cart = {
	er_after_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_after */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_after_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0086 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_after_cart = {
	t_after_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type f_after */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node f_after_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0087 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart f_after_cart = {
	f_after_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ae_after */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ae_after_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0088 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ae_after_cart = {
	ae_after_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_just */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_just_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0089 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_just_cart = {
	t_just_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type s_just */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node s_just_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0090 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart s_just_cart = {
	s_just_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ah_just */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ah_just_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0091 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ah_just_cart = {
	ah_just_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type jh_just */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node jh_just_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0092 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart jh_just_cart = {
	jh_just_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_ng */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_ng_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0093 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_ng_cart = {
	pau_ng_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ng_morning */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ng_morning_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0094 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ng_morning_cart = {
	ng_morning_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_morning */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_morning_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0095 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_morning_cart = {
	ih_morning_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_morning */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_morning_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0096 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_morning_cart = {
	n_morning_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type r_morning */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node r_morning_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0097 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart r_morning_cart = {
	r_morning_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ao_morning */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ao_morning_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0098 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ao_morning_cart = {
	ao_morning_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type m_morning */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node m_morning_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0099 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart m_morning_cart = {
	m_morning_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_in */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_in_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0100 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_in_cart = {
	n_in_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_in */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_in_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0101 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_in_cart = {
	ih_in_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_n */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_n_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0102 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_n_cart = {
	pau_n_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_one */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_one_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0103 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_one_cart = {
	n_one_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ah_one */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ah_one_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0104 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ah_one_cart = {
	ah_one_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type w_one */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node w_one_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0105 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart w_one_cart = {
	w_one_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_past */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_past_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0106 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_past_cart = {
	t_past_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type s_past */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node s_past_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0107 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart s_past_cart = {
	s_past_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ae_past */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ae_past_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0108 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ae_past_cart = {
	ae_past_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type p_past */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node p_past_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0109 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart p_past_cart = {
	p_past_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type v_five */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node v_five_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0110 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart v_five_cart = {
	v_five_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ay_five */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ay_five_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0111 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ay_five_cart = {
	ay_five_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type f_five */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node f_five_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0112 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart f_five_cart = {
	f_five_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type iy_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node iy_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0113 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart iy_exactly_cart = {
	iy_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type l_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node l_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0114 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart l_exactly_cart = {
	l_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0115 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_exactly_cart = {
	t_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type k_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node k_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0116 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart k_exactly_cart = {
	k_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ae_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ae_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0117 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ae_exactly_cart = {
	ae_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type z_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node z_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0118 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart z_exactly_cart = {
	z_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type g_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node g_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0119 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart g_exactly_cart = {
	g_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_exactly */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_exactly_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0120 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_exactly_cart = {
	ih_exactly_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_aw */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_aw_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0121 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_aw_cart = {
	pau_aw_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type aw_now */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node aw_now_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0122 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart aw_now_cart = {
	aw_now_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type n_now */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node n_now_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0123 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart n_now_cart = {
	n_now_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type z_is */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node z_is_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0124 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart z_is_cart = {
	z_is_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ih_is */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ih_is_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0125 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ih_is_cart = {
	ih_is_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type m_time */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node m_time_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0126 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart m_time_cart = {
	m_time_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ay_time */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node ay_time_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0127 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ay_time_cart = {
	ay_time_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type t_time */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node t_time_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0128 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart t_time_cart = {
	t_time_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type ax_the */
/* Branch definitions */
#define CTNODE_ax_the_NO_0000 2
/* CART nodes */
static const cst_cart_node ax_the_cart_nodes[] = {
	{ 0 /* R:SylStructure.parent.R:Syllable.p.syl_break */,
	  CST_CART_OP_IS, CTNODE_ax_the_NO_0000,
	  (cst_val *) &val_0000 /* 0 */ },
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0129 },
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0130 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart ax_the_cart = {
	ax_the_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type dh_the */
/* Branch definitions */
#define CTNODE_dh_the_NO_0000 2
/* CART nodes */
static const cst_cart_node dh_the_cart_nodes[] = {
	{ 1 /* p.name */,
	  CST_CART_OP_IS, CTNODE_dh_the_NO_0000,
	  (cst_val *) &val_0001 /* n */ },
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0131 },
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0132 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart dh_the_cart = {
	dh_the_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_pau */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_pau_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0133 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_pau_cart = {
	pau_pau_cart_nodes,
	cmu_time_awb_feature_table,
};


/* CART tree for unit type pau_0 */
/* Branch definitions */
/* CART nodes */
static const cst_cart_node pau_0_cart_nodes[] = {
	{ 255, CST_CART_OP_NONE, 0, (cst_val *) &cl_0134 },
	{ 255, CST_CART_OP_NONE, 0, 0}
};

/* CART structure */
static const cst_cart pau_0_cart = {
	pau_0_cart_nodes,
	cmu_time_awb_feature_table,
};


const cst_cart * const cmu_time_awb_carts[] = {
	&ae_after_cart,
	&ae_afternoon_cart,
	&ae_exactly_cart,
	&ae_half_cart,
	&ae_past_cart,
	&ah_just_cart,
	&ah_one_cart,
	&ao_almost_cart,
	&ao_four_cart,
	&ao_morning_cart,
	&ao_quarter_cart,
	&aw_now_cart,
	&ax_a_cart,
	&ax_eleven_cart,
	&ax_little_cart,
	&ax_seven_cart,
	&ax_the_cart,
	&ax_to_cart,
	&ay_five_cart,
	&ay_midnight_cart,
	&ay_nine_cart,
	&ay_time_cart,
	&d_midnight_cart,
	&dh_the_cart,
	&eh_eleven_cart,
	&eh_seven_cart,
	&eh_ten_cart,
	&eh_twelve_cart,
	&eh_twenty_cart,
	&er_after_cart,
	&er_afternoon_cart,
	&er_quarter_cart,
	&ey_eight_cart,
	&f_after_cart,
	&f_afternoon_cart,
	&f_five_cart,
	&f_four_cart,
	&f_half_cart,
	&g_exactly_cart,
	&hh_half_cart,
	&ih_eleven_cart,
	&ih_evening_cart,
	&ih_exactly_cart,
	&ih_in_cart,
	&ih_is_cart,
	&ih_little_cart,
	&ih_midnight_cart,
	&ih_morning_cart,
	&ih_six_cart,
	&iy_evening_cart,
	&iy_exactly_cart,
	&iy_the_cart,
	&iy_three_cart,
	&iy_twenty_cart,
	&jh_just_cart,
	&k_exactly_cart,
	&k_quarter_cart,
	&k_six_cart,
	&l_almost_cart,
	&l_eleven_cart,
	&l_exactly_cart,
	&l_little_cart,
	&l_twelve_cart,
	&m_almost_cart,
	&m_midnight_cart,
	&m_morning_cart,
	&m_time_cart,
	&n_afternoon_cart,
	&n_eleven_cart,
	&n_evening_cart,
	&n_in_cart,
	&n_midnight_cart,
	&n_morning_cart,
	&n_nine_cart,
	&n_now_cart,
	&n_one_cart,
	&n_seven_cart,
	&n_ten_cart,
	&n_twenty_cart,
	&ng_evening_cart,
	&ng_morning_cart,
	&ow_almost_cart,
	&p_past_cart,
	&pau_0_cart,
	&pau_aw_cart,
	&pau_iy_cart,
	&pau_n_cart,
	&pau_ng_cart,
	&pau_pau_cart,
	&pau_r_cart,
	&pau_s_cart,
	&pau_t_cart,
	&pau_uw_cart,
	&pau_v_cart,
	&r_four_cart,
	&r_morning_cart,
	&r_quarter_cart,
	&r_three_cart,
	&s_almost_cart,
	&s_just_cart,
	&s_past_cart,
	&s_seven_cart,
	&s_six_cart,
	&t_after_cart,
	&t_afternoon_cart,
	&t_almost_cart,
	&t_eight_cart,
	&t_exactly_cart,
	&t_just_cart,
	&t_little_cart,
	&t_midnight_cart,
	&t_past_cart,
	&t_quarter_cart,
	&t_ten_cart,
	&t_time_cart,
	&t_to_cart,
	&t_twelve_cart,
	&t_twenty_cart,
	&t_two_cart,
	&th_three_cart,
	&uw_afternoon_cart,
	&uw_two_cart,
	&v_eleven_cart,
	&v_evening_cart,
	&v_five_cart,
	&v_seven_cart,
	&v_twelve_cart,
	&w_one_cart,
	&w_quarter_cart,
	&w_twelve_cart,
	&w_twenty_cart,
	&z_exactly_cart,
	&z_is_cart,
	0
};
